@@ -28,7 +28,7 @@ extern "C" {
  * has been modified, and reset anytime the major API version has
  * been changed. Used to keep track if a field has been added or not.
  */
-#define SVT_AV1_ENC_ABI_VERSION 8
+#define SVT_AV1_ENC_ABI_VERSION 0
 
 //***HME***
 
@@ -435,7 +435,7 @@ typedef struct EbSvtAv1EncConfiguration {
     /* Target bitrate in bits/second, only applicable when rate control mode is
      * set to 1 (VBR) or 2 (CBR).
      *
-     * Default is 2000000. */
+     * Default is 2000513. */
     uint32_t target_bit_rate;
     /* maximum bitrate in bits/second, only apllicable when rate control mode is
      * set to 0.
@@ -454,13 +454,14 @@ typedef struct EbSvtAv1EncConfiguration {
      * Default is 63. */
     uint32_t max_qp_allowed;
     /* Minimum QP value allowed for rate control use, only applicable when rate
-     * control mode is set to 1. It has to be smaller or equal to maxQpAllowed.
+     * control mode is set to 1 or 2. It has to be smaller or equal to maxQpAllowed.
      *
-     * Default is 0. */
+     * Default is 4. */
     uint32_t min_qp_allowed;
 
     // DATARATE CONTROL OPTIONS
-
+#if !SVT_AV1_CHECK_VERSION(2, 0, 0)
+    /* DEPRECATED: to be removed in 2.0.0. */
     /**
      * @brief Variable Bit Rate Bias Percentage
      *
@@ -473,6 +474,7 @@ typedef struct EbSvtAv1EncConfiguration {
      * Default is 100
      */
     uint32_t vbr_bias_pct;
+#endif
 
     /**
      * @brief Variable Bit Rate Minimum Section Percentage
@@ -508,7 +510,7 @@ typedef struct EbSvtAv1EncConfiguration {
      *
      * Min is 0.
      * Max is 100.
-     * Default is 25.
+     * Default is 25 for CBR and 50 for VBR.
      */
     uint32_t under_shoot_pct;
 
@@ -629,7 +631,8 @@ typedef struct EbSvtAv1EncConfiguration {
     *
     * 0 is no denoising
     * 1 is full denoising
-    */
+    *
+    * Default is 0. */
     uint8_t film_grain_denoise_apply;
 
     /* CDEF Level
@@ -736,12 +739,19 @@ typedef struct EbSvtAv1EncConfiguration {
     /* DEPRECATED: to be removed in 1.5.0. */
     int32_t manual_pred_struct_entry_num;
 #endif
+#if OPT_FAST_DECODE_LVLS
+    /* Decoder-speed-targeted encoder optimization level (produce bitstreams that can be decoded faster).
+    * 0: No decoder speed optimization
+    * -1, 1, 2, 3,..: Decoder speed optimization enabled
+    */
+    int8_t fast_decode;
+#else
     /* Decoder-speed-targeted encoder optimization level (produce bitstreams that can be decoded faster).
     * 0: No decoder speed optimization
     * 1: Decoder speed optimization enabled (fast decode)
     */
     Bool fast_decode;
-
+#endif
     /* S-Frame interval (frames)
     * 0: S-Frame off
     * >0: S-Frame on and indicates the number of frames after which a frame may be coded as an S-Frame
@@ -920,14 +930,39 @@ typedef struct EbSvtAv1EncConfiguration {
      */
     SvtAv1FrameScaleEvts frame_scale_evts;
 
-    /*Add 64 Byte Padding to Struct to avoid changing the size of the public configuration struct*/
     /* ROI map
     *
     * 0 = disable ROI
     * 1 = enable ROI
     *  Default is 0. */
-    Bool    enable_roi_map;
-    uint8_t padding[64 - sizeof(Bool)];
+    Bool enable_roi_map;
+
+    /* Stores the optional film grain synthesis info */
+    AomFilmGrain *fgs_table;
+
+    /* New parameters can go in under this line. Also deduct the size of the parameter */
+    /* from the padding array */
+
+    /* Variance boost
+     * false = disable variance boost
+     * true = enable variance boost
+     * Default is false. */
+    Bool enable_variance_boost;
+
+    /* @brief Selects the curve strength to boost low variance regions according to a fast-growing formula
+     * Default is 2 */
+    uint8_t variance_boost_strength;
+
+    /* @brief Picks a set of eight 8x8 variance values per superblock to determine boost
+     * Lower values enable detecting more blocks that need boosting, at the expense of more possible false positives (overall bitrate increase)
+     *  1: 1st octile
+     *  4: 4th octile
+     *  8: 8th octile
+     *  Default is 6 */
+    uint8_t variance_octile;
+
+    /*Add 128 Byte Padding to Struct to avoid changing the size of the public configuration struct*/
+    uint8_t padding[128 - sizeof(Bool) - 2 * sizeof(uint8_t)];
 
 } EbSvtAv1EncConfiguration;
 
