@@ -38,26 +38,24 @@ extern "C" {
 #define CDEF_VERY_LARGE ((uint8_t)~0 >> 1 | ((uint8_t)~0 >> 1) << 8)
 #define CDEF_INBUF_SIZE (CDEF_BSTRIDE * ((1 << MAX_SB_SIZE_LOG2) + 2 * CDEF_VBORDER))
 
-extern const int32_t eb_cdef_pri_taps[2][2];
-extern const int32_t eb_cdef_sec_taps[2][2];
-extern const int (*const eb_cdef_directions)[2];
+extern const int32_t svt_aom_eb_cdef_pri_taps[2][2];
+extern const int32_t svt_aom_eb_cdef_sec_taps[2][2];
+extern const int (*const svt_aom_eb_cdef_directions)[2];
 
 #define REDUCED_PRI_STRENGTHS 8
 #define REDUCED_TOTAL_STRENGTHS (REDUCED_PRI_STRENGTHS * CDEF_SEC_STRENGTHS)
 #define TOTAL_STRENGTHS (CDEF_PRI_STRENGTHS * CDEF_SEC_STRENGTHS)
 
-void fill_rect(uint16_t *dst, int32_t dstride, int32_t v, int32_t h, uint16_t x);
-void copy_sb8_16(uint16_t *dst, int32_t dstride, const uint8_t *src, int32_t src_voffset,
-                 int32_t src_hoffset, int32_t sstride, int32_t vsize, int32_t hsize, Bool is_16bit);
+void svt_aom_fill_rect(uint16_t *dst, int32_t dstride, int32_t v, int32_t h, uint16_t x);
+void svt_aom_copy_sb8_16(uint16_t *dst, int32_t dstride, const uint8_t *src, int32_t src_voffset, int32_t src_hoffset,
+                         int32_t sstride, int32_t vsize, int32_t hsize, Bool is_16bit);
 
-void copy_rect(uint16_t *dst, int32_t dstride, const uint16_t *src, int32_t sstride, int32_t v,
-               int32_t h);
-void svt_cdef_filter_fb(uint8_t *dst8, uint16_t *dst16, int32_t dstride, uint16_t *in, int32_t xdec,
-                        int32_t ydec, uint8_t dir[CDEF_NBLOCKS][CDEF_NBLOCKS], int32_t *dirinit,
-                        int32_t var[CDEF_NBLOCKS][CDEF_NBLOCKS], int32_t pli, CdefList *dlist,
-                        int32_t cdef_count, int32_t level, int32_t sec_strength,
-                        int32_t pri_damping, int32_t sec_damping, int32_t coeff_shift,
-                        uint8_t subsampling_factor);
+void svt_aom_copy_rect(uint16_t *dst, int32_t dstride, const uint16_t *src, int32_t sstride, int32_t v, int32_t h);
+void svt_cdef_filter_fb(uint8_t *dst8, uint16_t *dst16, int32_t dstride, uint16_t *in, int32_t xdec, int32_t ydec,
+                        uint8_t dir[CDEF_NBLOCKS][CDEF_NBLOCKS], int32_t *dirinit,
+                        int32_t var[CDEF_NBLOCKS][CDEF_NBLOCKS], int32_t pli, CdefList *dlist, int32_t cdef_count,
+                        int32_t level, int32_t sec_strength, int32_t pri_damping, int32_t sec_damping,
+                        int32_t coeff_shift, uint8_t subsampling_factor);
 
 #ifdef __cplusplus
 }
