@@ -50,7 +50,8 @@
 #ifdef _WIN32
 uint8_t        num_groups = 0;
 GROUP_AFFINITY svt_aom_group_affinity;
-Bool           alternate_groups = 0;
+Bool           alternate_groups               = 0;
+int8_t         svt_aom_group_affinity_enabled = 0;
 #elif defined(__linux__)
 cpu_set_t svt_aom_group_affinity;
 #endif
@@ -507,7 +508,7 @@ EB_API EbErrorType svt_av1_dec_init(EbComponentType *svt_dec_component) {
         return EB_ErrorBadParameter;
 
     EbDecHandle *dec_handle_ptr = (EbDecHandle *)svt_dec_component->p_component_private;
-#ifdef ARCH_X86_64
+#if defined ARCH_X86_64 || defined ARCH_AARCH64
     EbCpuFlags cpu_flags = svt_aom_get_cpu_flags_to_use();
 #else
     EbCpuFlags cpu_flags = 0;
@@ -534,7 +535,9 @@ EB_API EbErrorType svt_av1_dec_init(EbComponentType *svt_dec_component) {
     svt_aom_asm_set_convolve_hbd_asm_table();
 
     svt_aom_init_intra_predictors_internal();
-
+#ifdef MINIMAL_BUILD
+    svt_aom_blk_geom_mds = svt_aom_malloc(MAX_NUM_BLOCKS_ALLOC * sizeof(svt_aom_blk_geom_mds[0]));
+#endif
     svt_av1_init_wedge_masks();
 
     /************************************
@@ -642,6 +645,9 @@ EB_API EbErrorType svt_av1_dec_deinit(EbComponentType *svt_dec_component) {
         free(tmp_memory_entry);
     } while (memory_entry != dec_handle_ptr->memory_map_init_address && memory_entry);
     free(dec_handle_ptr->memory_map_init_address);
+#ifdef MINIMAL_BUILD
+    svt_aom_free(svt_aom_blk_geom_mds);
+#endif
     return return_error;
 }
 
