@@ -239,8 +239,8 @@ void svt_av1_apply_zz_based_temporal_filter_planewise_medium_avx2(
 }
 static void svt_av1_apply_temporal_filter_planewise_medium_partial_avx2(
     struct MeContext *me_ctx, const uint8_t *y_src, int y_src_stride, const uint8_t *y_pre, int y_pre_stride,
-    unsigned int block_width, unsigned int block_height, uint32_t *y_accum, uint16_t *y_count,
-    const uint32_t tf_decay_factor, uint32_t luma_window_error_quad_fp8[4], int is_chroma) {
+    unsigned int block_width, unsigned int block_height, uint32_t *y_accum, uint16_t *y_count, uint32_t tf_decay_factor,
+    uint32_t luma_window_error_quad_fp8[4], int is_chroma) {
     unsigned int i, j, k, subblock_idx;
 
     int32_t  idx_32x32               = me_ctx->tf_block_col + me_ctx->tf_block_row * 2;
@@ -264,6 +264,7 @@ static void svt_av1_apply_temporal_filter_planewise_medium_partial_avx2(
             block_error_fp8[i] = (uint32_t)(me_ctx->tf_16x16_block_error[idx_32x32 * 4 + i]);
         }
     } else {
+        tf_decay_factor <<= 1;
         int32_t col = me_ctx->tf_32x32_mv_x[idx_32x32];
         int32_t row = me_ctx->tf_32x32_mv_y[idx_32x32];
 
@@ -322,9 +323,8 @@ static void svt_av1_apply_temporal_filter_planewise_medium_partial_avx2(
                                        block_error_fp8[subblock_idx]) /
             (TF_WINDOW_BLOCK_BALANCE_WEIGHT + 1);
 
-        uint32_t avg_err_fp10 = ((combined_error_fp8 >> 3) * (d_factor_fp8[subblock_idx] >> 3));
-        FP_ASSERT((((int64_t)combined_error_fp8 >> 3) * (d_factor_fp8[subblock_idx] >> 3)) < ((int64_t)1 << 31));
-        uint32_t scaled_diff16 = AOMMIN(
+        uint64_t avg_err_fp10  = ((combined_error_fp8 >> 3) * (d_factor_fp8[subblock_idx] >> 3));
+        uint32_t scaled_diff16 = (uint32_t)AOMMIN(
             /*((16*avg_err)<<8)*/ (avg_err_fp10) / AOMMAX((tf_decay_factor >> 10), 1), 7 * 16);
         uint32_t adjusted_weight = (expf_tab_fp16[scaled_diff16] * TF_WEIGHT_SCALE) >> 16;
 
@@ -501,8 +501,8 @@ void svt_av1_apply_zz_based_temporal_filter_planewise_medium_hbd_avx2(
 
 static void svt_av1_apply_temporal_filter_planewise_medium_hbd_partial_avx2(
     struct MeContext *me_ctx, const uint16_t *y_src, int y_src_stride, const uint16_t *y_pre, int y_pre_stride,
-    unsigned int block_width, unsigned int block_height, uint32_t *y_accum, uint16_t *y_count,
-    const uint32_t tf_decay_factor, uint32_t luma_window_error_quad_fp8[4], int is_chroma, uint32_t encoder_bit_depth) {
+    unsigned int block_width, unsigned int block_height, uint32_t *y_accum, uint16_t *y_count, uint32_t tf_decay_factor,
+    uint32_t luma_window_error_quad_fp8[4], int is_chroma, uint32_t encoder_bit_depth) {
     unsigned int i, j, k, subblock_idx;
 
     int32_t  idx_32x32               = me_ctx->tf_block_col + me_ctx->tf_block_row * 2;
@@ -526,6 +526,7 @@ static void svt_av1_apply_temporal_filter_planewise_medium_hbd_partial_avx2(
             block_error_fp8[i] = (uint32_t)(me_ctx->tf_16x16_block_error[idx_32x32 * 4 + i] >> 4);
         }
     } else {
+        tf_decay_factor <<= 1;
         int32_t col = me_ctx->tf_32x32_mv_x[idx_32x32];
         int32_t row = me_ctx->tf_32x32_mv_y[idx_32x32];
 
@@ -592,9 +593,8 @@ static void svt_av1_apply_temporal_filter_planewise_medium_hbd_partial_avx2(
                                        block_error_fp8[subblock_idx]) /
             (TF_WINDOW_BLOCK_BALANCE_WEIGHT + 1);
 
-        uint32_t avg_err_fp10 = ((combined_error_fp8 >> 3) * (d_factor_fp8[subblock_idx] >> 3));
-        FP_ASSERT((((int64_t)combined_error_fp8 >> 3) * (d_factor_fp8[subblock_idx] >> 3)) < ((int64_t)1 << 31));
-        uint32_t scaled_diff16 = AOMMIN(
+        uint64_t avg_err_fp10  = ((combined_error_fp8 >> 3) * (d_factor_fp8[subblock_idx] >> 3));
+        uint32_t scaled_diff16 = (uint32_t)AOMMIN(
             /*((16*avg_err)<<8)*/ (avg_err_fp10) / AOMMAX((tf_decay_factor >> 10), 1), 7 * 16);
         int adjusted_weight = (expf_tab_fp16[scaled_diff16] * TF_WEIGHT_SCALE) >> 16;
 
