@@ -22,11 +22,19 @@ static void mode_decision_context_dctor(EbPtr p) {
     ModeDecisionContext *obj = (ModeDecisionContext *)p;
 
     uint32_t block_max_count_sb = obj->init_max_block_cnt;
-    for (int cd = 0; cd < MAX_PAL_CAND; cd++)
-        if (obj->palette_cand_array[cd].color_idx_map)
-            EB_FREE_ARRAY(obj->palette_cand_array[cd].color_idx_map);
 
     // MD palette search
+    if (obj->palette_buffer)
+        EB_FREE(obj->palette_buffer);
+    if (obj->palette_cand_array) {
+        // Free fields in palette_cand_array before freeing palette_cand_array
+        for (int cd = 0; cd < MAX_PAL_CAND; cd++) {
+            if (obj->palette_cand_array[cd].color_idx_map)
+                EB_FREE_ARRAY(obj->palette_cand_array[cd].color_idx_map);
+        }
+
+        EB_FREE_ARRAY(obj->palette_cand_array);
+    }
     if (obj->palette_size_array_0)
         EB_FREE_ARRAY(obj->palette_size_array_0);
     for (CandClass cand_class_it = CAND_CLASS_0; cand_class_it < CAND_CLASS_TOTAL; cand_class_it++)
@@ -48,18 +56,19 @@ static void mode_decision_context_dctor(EbPtr p) {
     EB_DELETE(obj->cand_bf_tx_depth_2);
     EB_FREE_ALIGNED_ARRAY(obj->cfl_temp_luma_recon16bit);
     EB_FREE_ALIGNED_ARRAY(obj->cfl_temp_luma_recon);
+    EB_FREE_ALIGNED_ARRAY(obj->pred_buf_q3);
     EB_FREE_ARRAY(obj->fast_cand_array);
     EB_FREE_ARRAY(obj->fast_cand_ptr_array);
     EB_FREE_2D(obj->injected_mvs);
     EB_FREE_ARRAY(obj->injected_ref_types);
     EB_FREE_ARRAY(obj->fast_cost_array);
     EB_FREE_ARRAY(obj->full_cost_array);
-    if (obj->md_local_blk_unit) {
+    if (obj->md_blk_arr_nsq) {
         for (int i = 0; i < 3; i++) {
-            EB_FREE_ARRAY(obj->md_local_blk_unit[0].neigh_left_recon_16bit[i]);
-            EB_FREE_ARRAY(obj->md_local_blk_unit[0].neigh_top_recon_16bit[i]);
-            EB_FREE_ARRAY(obj->md_local_blk_unit[0].neigh_left_recon[i]);
-            EB_FREE_ARRAY(obj->md_local_blk_unit[0].neigh_top_recon[i]);
+            EB_FREE_ARRAY(obj->md_blk_arr_nsq[0].neigh_left_recon_16bit[i]);
+            EB_FREE_ARRAY(obj->md_blk_arr_nsq[0].neigh_top_recon_16bit[i]);
+            EB_FREE_ARRAY(obj->md_blk_arr_nsq[0].neigh_left_recon[i]);
+            EB_FREE_ARRAY(obj->md_blk_arr_nsq[0].neigh_top_recon[i]);
         }
     }
     if (obj->md_blk_arr_nsq) {
@@ -67,14 +76,16 @@ static void mode_decision_context_dctor(EbPtr p) {
     }
     EB_FREE_ARRAY(obj->avail_blk_flag);
     EB_FREE_ARRAY(obj->cost_avail);
-    EB_FREE_ARRAY(obj->md_local_blk_unit);
     EB_FREE_ARRAY(obj->md_blk_arr_nsq);
     if (obj->rate_est_table)
         EB_FREE_ARRAY(obj->rate_est_table);
-    if (obj->pred0)
-        EB_FREE(obj->pred0);
-    if (obj->pred1)
-        EB_FREE(obj->pred1);
+
+    for (int i = 0; i < NEAREST_NEAR_MV_CNT; i++) {
+        if (obj->cmp_store.pred0_buf[i])
+            EB_FREE(obj->cmp_store.pred0_buf[i]);
+        if (obj->cmp_store.pred1_buf[i])
+            EB_FREE(obj->cmp_store.pred1_buf[i]);
+    }
     if (obj->residual1)
         EB_FREE(obj->residual1);
     if (obj->diff10)
@@ -91,7 +102,10 @@ static void mode_decision_context_dctor(EbPtr p) {
         EB_FREE(obj->wsrc_buf);
     if (obj->mask_buf)
         EB_FREE(obj->mask_buf);
-    EB_FREE_ARRAY(obj->mdc_sb_array);
+    EB_FREE_ARRAY(obj->mdc_sb_array.leaf_data_array);
+    EB_FREE_ARRAY(obj->mdc_sb_array.split_flag);
+    EB_FREE_ARRAY(obj->mdc_sb_array.refined_split_flag);
+    EB_FREE_ARRAY(obj->mdc_sb_array.consider_block);
     for (uint32_t txt_itr = 0; txt_itr < TX_TYPES; ++txt_itr) {
         EB_DELETE(obj->recon_coeff_ptr[txt_itr]);
         EB_DELETE(obj->recon_ptr[txt_itr]);
@@ -114,7 +128,7 @@ EbErrorType svt_aom_mode_decision_context_ctor(ModeDecisionContext *ctx, EbColor
                                                EncMode enc_mode, uint16_t max_block_cnt, uint32_t encoder_bit_depth,
                                                EbFifo *mode_decision_configuration_input_fifo_ptr,
                                                EbFifo *mode_decision_output_fifo_ptr, uint8_t enable_hbd_mode_decision,
-                                               uint8_t cfg_palette, bool rtc_tune) {
+                                               uint8_t cfg_palette) {
     uint32_t buffer_index;
     uint32_t cand_index;
 
@@ -135,9 +149,10 @@ EbErrorType svt_aom_mode_decision_context_ctor(ModeDecisionContext *ctx, EbColor
     // determine MAX_NICS for a given preset
     // get the min scaling level (the smallest scaling level is the most conservative)
     uint8_t min_nic_scaling_level = NICS_SCALING_LEVELS - 1;
-    for (uint8_t hl = 0; hl < MAX_TEMPORAL_LAYERS; hl++) {
-        for (uint8_t is_base = 0; is_base < 2; is_base++) {
-            uint8_t nic_level         = svt_aom_get_nic_level(enc_mode, is_base, hl, rtc_tune);
+    for (uint8_t is_base = 0; is_base < 2; is_base++) {
+        // min QP is 1 b/c 0 is lossless and is not supported
+        for (uint8_t qp = 1; qp <= MAX_QP_VALUE; qp++) {
+            uint8_t nic_level         = svt_aom_get_nic_level(enc_mode, is_base, qp);
             uint8_t nic_scaling_level = svt_aom_set_nic_controls(NULL, nic_level);
             min_nic_scaling_level     = MIN(min_nic_scaling_level, nic_scaling_level);
         }
@@ -175,6 +190,7 @@ EbErrorType svt_aom_mode_decision_context_ctor(ModeDecisionContext *ctx, EbColor
         EB_MALLOC_ALIGNED(ctx->cfl_temp_luma_recon16bit, sizeof(uint16_t) * sb_size * sb_size);
     if (ctx->hbd_md != EB_10_BIT_MD)
         EB_MALLOC_ALIGNED(ctx->cfl_temp_luma_recon, sizeof(uint8_t) * sb_size * sb_size);
+    EB_MALLOC_ALIGNED(ctx->pred_buf_q3, CFL_BUF_SQUARE);
     uint8_t use_update_cdf = 0;
     for (uint8_t is_islice = 0; is_islice < 2; is_islice++) {
         for (uint8_t is_base = 0; is_base < 2; is_base++) {
@@ -190,8 +206,10 @@ EbErrorType svt_aom_mode_decision_context_ctor(ModeDecisionContext *ctx, EbColor
     // Allocate buffer for inter-inter compound prediction
     if (get_inter_compound_level(enc_mode)) {
         const uint8_t bits = ctx->hbd_md > EB_8_BIT_MD ? 2 : 1;
-        EB_MALLOC(ctx->pred0, sb_size * sb_size * bits * sizeof(ctx->pred0[0]));
-        EB_MALLOC(ctx->pred1, sb_size * sb_size * bits * sizeof(ctx->pred1[0]));
+        for (int i = 0; i < NEAREST_NEAR_MV_CNT; i++) {
+            EB_MALLOC(ctx->cmp_store.pred0_buf[i], sb_size * sb_size * bits * sizeof(uint8_t));
+            EB_MALLOC(ctx->cmp_store.pred1_buf[i], sb_size * sb_size * bits * sizeof(uint8_t));
+        }
         EB_MALLOC(ctx->residual1, sb_size * sb_size * sizeof(ctx->residual1[0]));
         EB_MALLOC(ctx->diff10, sb_size * sb_size * sizeof(ctx->diff10[0]));
     }
@@ -213,13 +231,12 @@ EbErrorType svt_aom_mode_decision_context_ctor(ModeDecisionContext *ctx, EbColor
 
     // Allocate buffers for obmc prediction
     uint8_t obmc_allowed = 0;
-    for (uint8_t is_ref = 0; is_ref < 2; is_ref++) {
-        for (uint8_t fast_decode = 0; fast_decode < 2; fast_decode++) {
-            for (EbInputResolution input_resolution = 0; input_resolution < INPUT_SIZE_COUNT; input_resolution++) {
-                if (obmc_allowed)
-                    break;
-                obmc_allowed |= svt_aom_get_obmc_level(enc_mode, fast_decode, input_resolution);
-            }
+    for (uint8_t is_base = 0; is_base < 2; is_base++) {
+        // min QP is 1 b/c 0 is lossless and is not supported
+        for (uint8_t qp = 1; qp <= MAX_QP_VALUE; qp++) {
+            if (obmc_allowed)
+                break;
+            obmc_allowed |= svt_aom_get_obmc_level(enc_mode, qp, is_base);
         }
     }
     if (obmc_allowed) {
@@ -229,7 +246,6 @@ EbErrorType svt_aom_mode_decision_context_ctor(ModeDecisionContext *ctx, EbColor
         EB_MALLOC(ctx->wsrc_buf, sb_size * sb_size * sizeof(ctx->wsrc_buf[0]));
         EB_MALLOC(ctx->mask_buf, sb_size * sb_size * sizeof(ctx->mask_buf[0]));
     }
-    EB_MALLOC_ARRAY(ctx->md_local_blk_unit, block_max_count_sb);
     EB_MALLOC_ARRAY(ctx->md_blk_arr_nsq, block_max_count_sb);
     // Fast Candidate Array
     uint16_t max_can_count = svt_aom_get_max_can_count(enc_mode) + ind_uv_cands;
@@ -245,14 +261,19 @@ EbErrorType svt_aom_mode_decision_context_ctor(ModeDecisionContext *ctx, EbColor
         ctx->fast_cand_ptr_array[cand_index]->palette_info = NULL;
     }
 
-    for (int cd = 0; cd < MAX_PAL_CAND; cd++)
-        if (cfg_palette)
-            EB_MALLOC_ARRAY(ctx->palette_cand_array[cd].color_idx_map, MAX_PALETTE_SQUARE);
-        else
-            ctx->palette_cand_array[cd].color_idx_map = NULL;
-
     // MD palette search
-    EB_MALLOC_ARRAY(ctx->palette_size_array_0, MAX_PAL_CAND);
+    if (cfg_palette) {
+        EB_MALLOC(ctx->palette_buffer, sizeof(PALETTE_BUFFER));
+        EB_MALLOC_ARRAY(ctx->palette_cand_array, MAX_PAL_CAND);
+        for (int cd = 0; cd < MAX_PAL_CAND; cd++)
+            EB_MALLOC_ARRAY(ctx->palette_cand_array[cd].color_idx_map, MAX_PALETTE_SQUARE);
+
+        EB_MALLOC_ARRAY(ctx->palette_size_array_0, MAX_PAL_CAND);
+    } else {
+        ctx->palette_buffer       = NULL;
+        ctx->palette_cand_array   = NULL;
+        ctx->palette_size_array_0 = NULL;
+    }
 
     // Cost Arrays
     EB_MALLOC_ARRAY(ctx->fast_cost_array, ctx->max_nics_uv);
@@ -272,71 +293,68 @@ EbErrorType svt_aom_mode_decision_context_ctor(ModeDecisionContext *ctx, EbColor
 
     EB_ALLOC_PTR_ARRAY(ctx->cand_bf_tx_depth_2->cand, 1);
     for (int i = 0; i < 3; i++) {
-        ctx->md_local_blk_unit[0].neigh_left_recon[i]       = NULL;
-        ctx->md_local_blk_unit[0].neigh_top_recon[i]        = NULL;
-        ctx->md_local_blk_unit[0].neigh_left_recon_16bit[i] = NULL;
-        ctx->md_local_blk_unit[0].neigh_top_recon_16bit[i]  = NULL;
+        ctx->md_blk_arr_nsq[0].neigh_left_recon[i]       = NULL;
+        ctx->md_blk_arr_nsq[0].neigh_top_recon[i]        = NULL;
+        ctx->md_blk_arr_nsq[0].neigh_left_recon_16bit[i] = NULL;
+        ctx->md_blk_arr_nsq[0].neigh_top_recon_16bit[i]  = NULL;
     }
     uint16_t sz = sizeof(uint16_t);
     if (ctx->hbd_md > EB_8_BIT_MD) {
-        EB_MALLOC_ARRAY(ctx->md_local_blk_unit[0].neigh_left_recon_16bit[0], block_max_count_sb * sb_size * sz);
-        EB_MALLOC_ARRAY(ctx->md_local_blk_unit[0].neigh_top_recon_16bit[0], block_max_count_sb * sb_size * sz);
-        EB_MALLOC_ARRAY(ctx->md_local_blk_unit[0].neigh_left_recon_16bit[1], block_max_count_sb * sb_size * sz >> 1);
-        EB_MALLOC_ARRAY(ctx->md_local_blk_unit[0].neigh_top_recon_16bit[1], block_max_count_sb * sb_size * sz >> 1);
-        EB_MALLOC_ARRAY(ctx->md_local_blk_unit[0].neigh_left_recon_16bit[2], block_max_count_sb * sb_size * sz >> 1);
-        EB_MALLOC_ARRAY(ctx->md_local_blk_unit[0].neigh_top_recon_16bit[2], block_max_count_sb * sb_size * sz >> 1);
+        EB_MALLOC_ARRAY(ctx->md_blk_arr_nsq[0].neigh_left_recon_16bit[0], block_max_count_sb * sb_size * sz);
+        EB_MALLOC_ARRAY(ctx->md_blk_arr_nsq[0].neigh_top_recon_16bit[0], block_max_count_sb * sb_size * sz);
+        EB_MALLOC_ARRAY(ctx->md_blk_arr_nsq[0].neigh_left_recon_16bit[1], block_max_count_sb * sb_size * sz >> 1);
+        EB_MALLOC_ARRAY(ctx->md_blk_arr_nsq[0].neigh_top_recon_16bit[1], block_max_count_sb * sb_size * sz >> 1);
+        EB_MALLOC_ARRAY(ctx->md_blk_arr_nsq[0].neigh_left_recon_16bit[2], block_max_count_sb * sb_size * sz >> 1);
+        EB_MALLOC_ARRAY(ctx->md_blk_arr_nsq[0].neigh_top_recon_16bit[2], block_max_count_sb * sb_size * sz >> 1);
     }
     if (ctx->hbd_md != EB_10_BIT_MD) {
-        EB_MALLOC_ARRAY(ctx->md_local_blk_unit[0].neigh_left_recon[0], block_max_count_sb * sb_size);
-        EB_MALLOC_ARRAY(ctx->md_local_blk_unit[0].neigh_top_recon[0], block_max_count_sb * sb_size);
-        EB_MALLOC_ARRAY(ctx->md_local_blk_unit[0].neigh_left_recon[1], block_max_count_sb * sb_size >> 1);
-        EB_MALLOC_ARRAY(ctx->md_local_blk_unit[0].neigh_top_recon[1], block_max_count_sb * sb_size >> 1);
-        EB_MALLOC_ARRAY(ctx->md_local_blk_unit[0].neigh_left_recon[2], block_max_count_sb * sb_size >> 1);
-        EB_MALLOC_ARRAY(ctx->md_local_blk_unit[0].neigh_top_recon[2], block_max_count_sb * sb_size >> 1);
+        EB_MALLOC_ARRAY(ctx->md_blk_arr_nsq[0].neigh_left_recon[0], block_max_count_sb * sb_size);
+        EB_MALLOC_ARRAY(ctx->md_blk_arr_nsq[0].neigh_top_recon[0], block_max_count_sb * sb_size);
+        EB_MALLOC_ARRAY(ctx->md_blk_arr_nsq[0].neigh_left_recon[1], block_max_count_sb * sb_size >> 1);
+        EB_MALLOC_ARRAY(ctx->md_blk_arr_nsq[0].neigh_top_recon[1], block_max_count_sb * sb_size >> 1);
+        EB_MALLOC_ARRAY(ctx->md_blk_arr_nsq[0].neigh_left_recon[2], block_max_count_sb * sb_size >> 1);
+        EB_MALLOC_ARRAY(ctx->md_blk_arr_nsq[0].neigh_top_recon[2], block_max_count_sb * sb_size >> 1);
     }
     uint32_t coded_leaf_index;
     for (coded_leaf_index = 0; coded_leaf_index < block_max_count_sb; ++coded_leaf_index) {
         size_t offset = coded_leaf_index * sb_size * sz;
-        ctx->md_local_blk_unit[coded_leaf_index].neigh_left_recon_16bit[0] =
-            ctx->md_local_blk_unit[0].neigh_left_recon_16bit[0] + offset;
-        ctx->md_local_blk_unit[coded_leaf_index].neigh_top_recon_16bit[0] =
-            ctx->md_local_blk_unit[0].neigh_top_recon_16bit[0] + offset;
+        ctx->md_blk_arr_nsq[coded_leaf_index].neigh_left_recon_16bit[0] =
+            ctx->md_blk_arr_nsq[0].neigh_left_recon_16bit[0] + offset;
+        ctx->md_blk_arr_nsq[coded_leaf_index].neigh_top_recon_16bit[0] =
+            ctx->md_blk_arr_nsq[0].neigh_top_recon_16bit[0] + offset;
         offset >>= 1;
-        ctx->md_local_blk_unit[coded_leaf_index].neigh_left_recon_16bit[1] =
-            ctx->md_local_blk_unit[0].neigh_left_recon_16bit[1] + offset;
-        ctx->md_local_blk_unit[coded_leaf_index].neigh_top_recon_16bit[1] =
-            ctx->md_local_blk_unit[0].neigh_top_recon_16bit[1] + offset;
-        ctx->md_local_blk_unit[coded_leaf_index].neigh_left_recon_16bit[2] =
-            ctx->md_local_blk_unit[0].neigh_left_recon_16bit[2] + offset;
-        ctx->md_local_blk_unit[coded_leaf_index].neigh_top_recon_16bit[2] =
-            ctx->md_local_blk_unit[0].neigh_top_recon_16bit[2] + offset;
+        ctx->md_blk_arr_nsq[coded_leaf_index].neigh_left_recon_16bit[1] =
+            ctx->md_blk_arr_nsq[0].neigh_left_recon_16bit[1] + offset;
+        ctx->md_blk_arr_nsq[coded_leaf_index].neigh_top_recon_16bit[1] =
+            ctx->md_blk_arr_nsq[0].neigh_top_recon_16bit[1] + offset;
+        ctx->md_blk_arr_nsq[coded_leaf_index].neigh_left_recon_16bit[2] =
+            ctx->md_blk_arr_nsq[0].neigh_left_recon_16bit[2] + offset;
+        ctx->md_blk_arr_nsq[coded_leaf_index].neigh_top_recon_16bit[2] =
+            ctx->md_blk_arr_nsq[0].neigh_top_recon_16bit[2] + offset;
 
-        offset                                                       = coded_leaf_index * sb_size;
-        ctx->md_local_blk_unit[coded_leaf_index].neigh_left_recon[0] = ctx->md_local_blk_unit[0].neigh_left_recon[0] +
-            offset;
-        ctx->md_local_blk_unit[coded_leaf_index].neigh_top_recon[0] = ctx->md_local_blk_unit[0].neigh_top_recon[0] +
-            offset;
+        offset                                                    = coded_leaf_index * sb_size;
+        ctx->md_blk_arr_nsq[coded_leaf_index].neigh_left_recon[0] = ctx->md_blk_arr_nsq[0].neigh_left_recon[0] + offset;
+        ctx->md_blk_arr_nsq[coded_leaf_index].neigh_top_recon[0]  = ctx->md_blk_arr_nsq[0].neigh_top_recon[0] + offset;
         offset >>= 1;
-        ctx->md_local_blk_unit[coded_leaf_index].neigh_left_recon[1] = ctx->md_local_blk_unit[0].neigh_left_recon[1] +
-            offset;
-        ctx->md_local_blk_unit[coded_leaf_index].neigh_top_recon[1] = ctx->md_local_blk_unit[0].neigh_top_recon[1] +
-            offset;
-        ctx->md_local_blk_unit[coded_leaf_index].neigh_left_recon[2] = ctx->md_local_blk_unit[0].neigh_left_recon[2] +
-            offset;
-        ctx->md_local_blk_unit[coded_leaf_index].neigh_top_recon[2] = ctx->md_local_blk_unit[0].neigh_top_recon[2] +
-            offset;
+        ctx->md_blk_arr_nsq[coded_leaf_index].neigh_left_recon[1] = ctx->md_blk_arr_nsq[0].neigh_left_recon[1] + offset;
+        ctx->md_blk_arr_nsq[coded_leaf_index].neigh_top_recon[1]  = ctx->md_blk_arr_nsq[0].neigh_top_recon[1] + offset;
+        ctx->md_blk_arr_nsq[coded_leaf_index].neigh_left_recon[2] = ctx->md_blk_arr_nsq[0].neigh_left_recon[2] + offset;
+        ctx->md_blk_arr_nsq[coded_leaf_index].neigh_top_recon[2]  = ctx->md_blk_arr_nsq[0].neigh_top_recon[2] + offset;
     }
     ctx->md_blk_arr_nsq[0].av1xd = NULL;
     EB_MALLOC_ARRAY(ctx->md_blk_arr_nsq[0].av1xd, block_max_count_sb);
     EB_MALLOC_ARRAY(ctx->avail_blk_flag, block_max_count_sb);
     EB_MALLOC_ARRAY(ctx->cost_avail, block_max_count_sb);
-    EB_MALLOC_ARRAY(ctx->mdc_sb_array, 1);
+    EB_MALLOC_ARRAY(ctx->mdc_sb_array.leaf_data_array, block_max_count_sb);
+    EB_MALLOC_ARRAY(ctx->mdc_sb_array.split_flag, block_max_count_sb);
+    EB_MALLOC_ARRAY(ctx->mdc_sb_array.refined_split_flag, block_max_count_sb);
+    EB_MALLOC_ARRAY(ctx->mdc_sb_array.consider_block, block_max_count_sb);
     for (coded_leaf_index = 0; coded_leaf_index < block_max_count_sb; ++coded_leaf_index) {
         ctx->md_blk_arr_nsq[coded_leaf_index].av1xd      = ctx->md_blk_arr_nsq[0].av1xd + coded_leaf_index;
         ctx->md_blk_arr_nsq[coded_leaf_index].segment_id = 0;
         const BlockGeom *blk_geom                        = get_blk_geom_mds(coded_leaf_index);
 
-        if (svt_aom_get_bypass_encdec(enc_mode, ctx->hbd_md, encoder_bit_depth)) {
+        if (svt_aom_get_bypass_encdec(enc_mode, encoder_bit_depth)) {
             EbPictureBufferDescInitData init_data;
 
             init_data.buffer_enable_mask = PICTURE_BUFFER_DESC_FULL_MASK;
@@ -477,7 +495,7 @@ void svt_aom_reset_mode_decision_neighbor_arrays(PictureControlSet *pcs, uint16_
             svt_aom_neighbor_array_unit_reset(pcs->md_cb_recon_na[depth][tile_idx]);
             svt_aom_neighbor_array_unit_reset(pcs->md_cr_recon_na[depth][tile_idx]);
         }
-        if (pcs->hbd_md > EB_8_BIT_MD) {
+        if (pcs->hbd_md > EB_8_BIT_MD || (pcs->scs->encoder_bit_depth > EB_EIGHT_BIT && pcs->pic_bypass_encdec)) {
             svt_aom_neighbor_array_unit_reset(pcs->md_luma_recon_na_16bit[depth][tile_idx]);
             svt_aom_neighbor_array_unit_reset(pcs->md_tx_depth_1_luma_recon_na_16bit[depth][tile_idx]);
             svt_aom_neighbor_array_unit_reset(pcs->md_tx_depth_2_luma_recon_na_16bit[depth][tile_idx]);
@@ -503,9 +521,9 @@ void svt_aom_reset_mode_decision_neighbor_arrays(PictureControlSet *pcs, uint16_
 // Testing showed that updating SAD lambda based on frame info was not helpful; therefore, the SAD lambda generation is not changed.
 static void av1_lambda_assign_md(PictureControlSet *pcs, ModeDecisionContext *ctx) {
     ctx->full_lambda_md[0] = (uint32_t)svt_aom_compute_rd_mult(pcs, ctx->qp_index, ctx->me_q_index, 8);
-    ctx->fast_lambda_md[0] = av1_lambda_mode_decision8_bit_sad[ctx->qp_index];
+    ctx->fast_lambda_md[0] = (uint32_t)svt_aom_compute_fast_lambda(pcs, ctx->qp_index, ctx->me_q_index, 8);
     ctx->full_lambda_md[1] = (uint32_t)svt_aom_compute_rd_mult(pcs, ctx->qp_index, ctx->me_q_index, 10);
-    ctx->fast_lambda_md[1] = av1lambda_mode_decision10_bit_sad[ctx->qp_index];
+    ctx->fast_lambda_md[1] = (uint32_t)svt_aom_compute_fast_lambda(pcs, ctx->qp_index, ctx->me_q_index, 10);
 
     if (pcs->scs->stats_based_sb_lambda_modulation) {
         if (pcs->temporal_layer_index > 0) {
@@ -517,7 +535,12 @@ static void av1_lambda_assign_md(PictureControlSet *pcs, ModeDecisionContext *ct
             }
         }
     }
-
+    if (pcs->lambda_weight) {
+        ctx->full_lambda_md[0] = (ctx->full_lambda_md[0] * pcs->lambda_weight) >> 7;
+        ctx->fast_lambda_md[0] = (ctx->fast_lambda_md[0] * pcs->lambda_weight) >> 7;
+        ctx->full_lambda_md[1] = (ctx->full_lambda_md[1] * pcs->lambda_weight) >> 7;
+        ctx->fast_lambda_md[1] = (ctx->fast_lambda_md[1] * pcs->lambda_weight) >> 7;
+    }
     ctx->full_lambda_md[1] *= 16;
     ctx->fast_lambda_md[1] *= 4;
 
@@ -589,7 +612,6 @@ void svt_aom_reset_mode_decision(SequenceControlSet *scs, ModeDecisionContext *c
     }
     //each segment enherits the bypass encdec from the picture level
     ctx->bypass_encdec = pcs->pic_bypass_encdec;
-    ctx->skip_pd0      = pcs->pic_skip_pd0;
     set_block_based_depth_refinement_controls(ctx, pcs->pic_block_based_depth_refinement_level);
     if (!pcs->rtc_tune || pcs->temporal_layer_index != 0)
         ctx->rtc_use_N4_dct_dct_shortcut = 1;
