@@ -315,6 +315,8 @@ typedef struct Me8x8VarCtrls {
     uint32_t me_sr_div4_th;
     // If ME 8x8 SAD variance is below me_sr_div2_th, divide the search area width/height by 2
     uint32_t me_sr_div2_th;
+    // If ME 8x8 SAD variance is above me_sr_mult2_th, multiply the search area width/height by 2
+    uint32_t me_sr_mult2_th;
 } Me8x8VarCtrls;
 #define SEARCH_REGION_COUNT 2
 typedef struct SearchArea {
@@ -463,6 +465,10 @@ typedef struct MeContext {
     signed short tf_16x16_mv_x[16];
     signed short tf_16x16_mv_y[16];
     uint64_t     tf_16x16_block_error[16];
+    signed short tf_8x8_mv_x[64];
+    signed short tf_8x8_mv_y[64];
+    uint64_t     tf_8x8_block_error[64];
+    int          tf_16x16_block_split_flag[4][4];
 
     signed short tf_32x32_mv_x[4];
     signed short tf_32x32_mv_y[4];
@@ -478,7 +484,7 @@ typedef struct MeContext {
     uint8_t      reduce_hme_l0_sr_th_max;
     uint16_t     tf_me_exit_th;
     uint8_t      tf_use_pred_64x64_only_th;
-    uint8_t      tf_subpel_early_exit;
+    uint8_t      tf_subpel_early_exit_th;
     uint32_t     zz_sad[MAX_NUM_OF_REF_PIC_LIST][REF_LIST_MAX_DEPTH];
     uint32_t     me_early_exit_th;
     uint32_t     me_safe_limit_zz_th;
