@@ -27,29 +27,26 @@ static void neighbor_array_unit_dctor32(EbPtr p) {
 /*************************************************
  * Neighbor Array Unit Ctor
  *************************************************/
-EbErrorType neighbor_array_unit_ctor32(NeighborArrayUnit32 *na_unit_ptr, uint32_t max_picture_width,
-                                       uint32_t max_picture_height, uint32_t unit_size,
-                                       uint32_t granularity_normal, uint32_t granularity_top_left,
-                                       uint32_t type_mask) {
+EbErrorType svt_aom_neighbor_array_unit_ctor32(NeighborArrayUnit32 *na_unit_ptr, uint32_t max_picture_width,
+                                               uint32_t max_picture_height, uint32_t unit_size,
+                                               uint8_t granularity_normal, uint8_t granularity_top_left,
+                                               uint8_t type_mask) {
     na_unit_ptr->dctor                     = neighbor_array_unit_dctor32;
     na_unit_ptr->unit_size                 = (uint8_t)(unit_size);
-    na_unit_ptr->granularity_normal        = (uint8_t)(granularity_normal);
+    na_unit_ptr->granularity_normal        = granularity_normal;
     na_unit_ptr->granularity_normal_log2   = (uint8_t)(svt_log2f(na_unit_ptr->granularity_normal));
-    na_unit_ptr->granularity_top_left      = (uint8_t)(granularity_top_left);
-    na_unit_ptr->granularity_top_left_log2 = (uint8_t)(svt_log2f(
-        na_unit_ptr->granularity_top_left));
+    na_unit_ptr->granularity_top_left      = granularity_top_left;
+    na_unit_ptr->granularity_top_left_log2 = (uint8_t)(svt_log2f(na_unit_ptr->granularity_top_left));
     na_unit_ptr->left_array_size           = (uint16_t)((type_mask & NEIGHBOR_ARRAY_UNIT_LEFT_MASK)
-                                                            ? max_picture_height >>
-                                                      na_unit_ptr->granularity_normal_log2
+                                                            ? max_picture_height >> na_unit_ptr->granularity_normal_log2
                                                             : 0);
     na_unit_ptr->top_array_size            = (uint16_t)((type_mask & NEIGHBOR_ARRAY_UNIT_TOP_MASK)
-                                                            ? max_picture_width >>
-                                                     na_unit_ptr->granularity_normal_log2
+                                                            ? max_picture_width >> na_unit_ptr->granularity_normal_log2
                                                             : 0);
-    na_unit_ptr->top_left_array_size = (uint16_t)((type_mask & NEIGHBOR_ARRAY_UNIT_TOPLEFT_MASK)
-                                                      ? (max_picture_width + max_picture_height) >>
+    na_unit_ptr->top_left_array_size       = (uint16_t)((type_mask & NEIGHBOR_ARRAY_UNIT_TOPLEFT_MASK)
+                                                            ? (max_picture_width + max_picture_height) >>
                                                           na_unit_ptr->granularity_top_left_log2
-                                                      : 0);
+                                                            : 0);
 
     if (na_unit_ptr->left_array_size) {
         EB_MALLOC(na_unit_ptr->left_array, na_unit_ptr->unit_size * na_unit_ptr->left_array_size);
@@ -60,8 +57,7 @@ EbErrorType neighbor_array_unit_ctor32(NeighborArrayUnit32 *na_unit_ptr, uint32_
     }
 
     if (na_unit_ptr->top_left_array_size) {
-        EB_MALLOC(na_unit_ptr->top_left_array,
-                  na_unit_ptr->unit_size * na_unit_ptr->top_left_array_size);
+        EB_MALLOC(na_unit_ptr->top_left_array, na_unit_ptr->unit_size * na_unit_ptr->top_left_array_size);
     }
     return EB_ErrorNone;
 }
@@ -73,27 +69,24 @@ static void neighbor_array_unit_dctor(EbPtr p) {
     EB_FREE(obj->top_left_array);
 }
 
-EbErrorType neighbor_array_unit_ctor(NeighborArrayUnit *na_unit_ptr, uint32_t max_picture_width,
-                                     uint32_t max_picture_height, uint32_t unit_size,
-                                     uint32_t granularity_normal, uint32_t granularity_top_left,
-                                     uint32_t type_mask) {
+EbErrorType svt_aom_neighbor_array_unit_ctor(NeighborArrayUnit *na_unit_ptr, uint32_t max_picture_width,
+                                             uint32_t max_picture_height, uint32_t unit_size,
+                                             uint8_t granularity_normal, uint8_t granularity_top_left,
+                                             uint8_t type_mask) {
     na_unit_ptr->dctor                     = neighbor_array_unit_dctor;
     na_unit_ptr->unit_size                 = (uint8_t)(unit_size);
-    na_unit_ptr->granularity_normal        = (uint8_t)(granularity_normal);
+    na_unit_ptr->granularity_normal        = granularity_normal;
     na_unit_ptr->granularity_normal_log2   = (uint8_t)(svt_log2f(na_unit_ptr->granularity_normal));
-    na_unit_ptr->granularity_top_left      = (uint8_t)(granularity_top_left);
-    na_unit_ptr->granularity_top_left_log2 = (uint8_t)(svt_log2f(
-        na_unit_ptr->granularity_top_left));
+    na_unit_ptr->granularity_top_left      = granularity_top_left;
+    na_unit_ptr->granularity_top_left_log2 = (uint8_t)(svt_log2f(na_unit_ptr->granularity_top_left));
 
     na_unit_ptr->max_pic_h = max_picture_height;
 
     na_unit_ptr->left_array_size     = (uint16_t)((type_mask & NEIGHBOR_ARRAY_UNIT_LEFT_MASK)
-                                                      ? max_picture_height >>
-                                                      na_unit_ptr->granularity_normal_log2
+                                                      ? max_picture_height >> na_unit_ptr->granularity_normal_log2
                                                       : 0);
     na_unit_ptr->top_array_size      = (uint16_t)((type_mask & NEIGHBOR_ARRAY_UNIT_TOP_MASK)
-                                                      ? max_picture_width >>
-                                                     na_unit_ptr->granularity_normal_log2
+                                                      ? max_picture_width >> na_unit_ptr->granularity_normal_log2
                                                       : 0);
     na_unit_ptr->top_left_array_size = (uint16_t)((type_mask & NEIGHBOR_ARRAY_UNIT_TOPLEFT_MASK)
                                                       ? (max_picture_width + max_picture_height) >>
@@ -107,8 +100,7 @@ EbErrorType neighbor_array_unit_ctor(NeighborArrayUnit *na_unit_ptr, uint32_t ma
         EB_MALLOC(na_unit_ptr->top_array, na_unit_ptr->unit_size * na_unit_ptr->top_array_size);
     }
     if (na_unit_ptr->top_left_array_size) {
-        EB_MALLOC(na_unit_ptr->top_left_array,
-                  na_unit_ptr->unit_size * na_unit_ptr->top_left_array_size);
+        EB_MALLOC(na_unit_ptr->top_left_array, na_unit_ptr->unit_size * na_unit_ptr->top_left_array_size);
     }
     return EB_ErrorNone;
 }
@@ -117,10 +109,9 @@ EbErrorType neighbor_array_unit_ctor(NeighborArrayUnit *na_unit_ptr, uint32_t ma
  * Neighbor Array Unit Reset
  *************************************************/
 
-void neighbor_array_unit_reset32(NeighborArrayUnit32 *na_unit_ptr) {
+void svt_aom_neighbor_array_unit_reset32(NeighborArrayUnit32 *na_unit_ptr) {
     if (na_unit_ptr->left_array) {
-        EB_MEMSET(
-            na_unit_ptr->left_array, ~0, na_unit_ptr->unit_size * na_unit_ptr->left_array_size);
+        EB_MEMSET(na_unit_ptr->left_array, ~0, na_unit_ptr->unit_size * na_unit_ptr->left_array_size);
     }
 
     if (na_unit_ptr->top_array) {
@@ -128,17 +119,14 @@ void neighbor_array_unit_reset32(NeighborArrayUnit32 *na_unit_ptr) {
     }
 
     if (na_unit_ptr->top_left_array) {
-        EB_MEMSET(na_unit_ptr->top_left_array,
-                  ~0,
-                  na_unit_ptr->unit_size * na_unit_ptr->top_left_array_size);
+        EB_MEMSET(na_unit_ptr->top_left_array, ~0, na_unit_ptr->unit_size * na_unit_ptr->top_left_array_size);
     }
 
     return;
 }
-void neighbor_array_unit_reset(NeighborArrayUnit *na_unit_ptr) {
+void svt_aom_neighbor_array_unit_reset(NeighborArrayUnit *na_unit_ptr) {
     if (na_unit_ptr->left_array) {
-        EB_MEMSET(
-            na_unit_ptr->left_array, ~0, na_unit_ptr->unit_size * na_unit_ptr->left_array_size);
+        EB_MEMSET(na_unit_ptr->left_array, ~0, na_unit_ptr->unit_size * na_unit_ptr->left_array_size);
     }
 
     if (na_unit_ptr->top_array) {
@@ -146,9 +134,7 @@ void neighbor_array_unit_reset(NeighborArrayUnit *na_unit_ptr) {
     }
 
     if (na_unit_ptr->top_left_array) {
-        EB_MEMSET(na_unit_ptr->top_left_array,
-                  ~0,
-                  na_unit_ptr->unit_size * na_unit_ptr->top_left_array_size);
+        EB_MEMSET(na_unit_ptr->top_left_array, ~0, na_unit_ptr->unit_size * na_unit_ptr->top_left_array_size);
     }
 
     return;
@@ -157,22 +143,20 @@ void neighbor_array_unit_reset(NeighborArrayUnit *na_unit_ptr) {
 /*************************************************
  * Neighbor Array Unit Get Top Index
  *************************************************/
-uint32_t get_neighbor_array_unit_top_left_index_32(NeighborArrayUnit32 *na_unit_ptr, int32_t loc_x,
-                                                   int32_t loc_y) {
+static uint32_t get_neighbor_array_unit_top_left_index_32(NeighborArrayUnit32 *na_unit_ptr, int32_t loc_x,
+                                                          int32_t loc_y) {
     return na_unit_ptr->left_array_size + (loc_x >> na_unit_ptr->granularity_top_left_log2) -
         (loc_y >> na_unit_ptr->granularity_top_left_log2);
 }
 
-uint32_t get_neighbor_array_unit_top_left_index(NeighborArrayUnit *na_unit_ptr, int32_t loc_x,
-                                                int32_t loc_y) {
+uint32_t svt_aom_get_neighbor_array_unit_top_left_index(NeighborArrayUnit *na_unit_ptr, int32_t loc_x, int32_t loc_y) {
     return na_unit_ptr->left_array_size + (loc_x >> na_unit_ptr->granularity_top_left_log2) -
         (loc_y >> na_unit_ptr->granularity_top_left_log2);
 }
 
-void update_recon_neighbor_array(NeighborArrayUnit *na_unit_ptr, uint8_t *src_ptr_top,
-                                 uint8_t *src_ptr_left, uint32_t pic_origin_x,
-                                 uint32_t pic_origin_y, uint32_t block_width,
-                                 uint32_t block_height) {
+void svt_aom_update_recon_neighbor_array(NeighborArrayUnit *na_unit_ptr, uint8_t *src_ptr_top, uint8_t *src_ptr_left,
+                                         uint32_t pic_origin_x, uint32_t pic_origin_y, uint32_t block_width,
+                                         uint32_t block_height) {
     uint8_t *dst_ptr;
 
     dst_ptr = na_unit_ptr->top_array +
@@ -201,7 +185,7 @@ void update_recon_neighbor_array(NeighborArrayUnit *na_unit_ptr, uint8_t *src_pt
         //  The top-left neighbor array is updated with the reversed samples
         //    from the right column and bottom row of the source block
         //
-        // Index = origin_x - origin_y
+        // Index = org_x - org_y
         */
 
     uint32_t idx;
@@ -218,8 +202,7 @@ void update_recon_neighbor_array(NeighborArrayUnit *na_unit_ptr, uint8_t *src_pt
     dst_ptr =
         //    topLeftArray_chkn+
         na_unit_ptr->top_left_array +
-        get_neighbor_array_unit_top_left_index(
-            na_unit_ptr, pic_origin_x, pic_origin_y + (block_height - 1)) *
+        svt_aom_get_neighbor_array_unit_top_left_index(na_unit_ptr, pic_origin_x, pic_origin_y + (block_height - 1)) *
             na_unit_ptr->unit_size;
 
     svt_memcpy(dst_ptr, read_ptr, block_width);
@@ -231,8 +214,7 @@ void update_recon_neighbor_array(NeighborArrayUnit *na_unit_ptr, uint8_t *src_pt
     dst_ptr =
         //  topLeftArray_chkn+
         na_unit_ptr->top_left_array +
-        get_neighbor_array_unit_top_left_index(
-            na_unit_ptr, pic_origin_x + (block_width - 1), pic_origin_y) *
+        svt_aom_get_neighbor_array_unit_top_left_index(na_unit_ptr, pic_origin_x + (block_width - 1), pic_origin_y) *
             na_unit_ptr->unit_size;
 
     dst_step  = -1;
@@ -249,19 +231,16 @@ void update_recon_neighbor_array(NeighborArrayUnit *na_unit_ptr, uint8_t *src_pt
     return;
 }
 
-void update_recon_neighbor_array16bit(NeighborArrayUnit *na_unit_ptr, uint16_t *src_ptr_top,
-                                      uint16_t *src_ptr_left, uint32_t pic_origin_x,
-                                      uint32_t pic_origin_y, uint32_t block_width,
-                                      uint32_t block_height) {
+void svt_aom_update_recon_neighbor_array16bit(NeighborArrayUnit *na_unit_ptr, uint16_t *src_ptr_top,
+                                              uint16_t *src_ptr_left, uint32_t pic_origin_x, uint32_t pic_origin_y,
+                                              uint32_t block_width, uint32_t block_height) {
     uint16_t *dst_ptr;
     dst_ptr = (uint16_t *)(na_unit_ptr->top_array +
-                           get_neighbor_array_unit_top_index(na_unit_ptr, pic_origin_x) *
-                               na_unit_ptr->unit_size);
+                           get_neighbor_array_unit_top_index(na_unit_ptr, pic_origin_x) * na_unit_ptr->unit_size);
     svt_memcpy(dst_ptr, src_ptr_top, block_width * sizeof(uint16_t));
 
     dst_ptr = (uint16_t *)(na_unit_ptr->left_array +
-                           get_neighbor_array_unit_left_index(na_unit_ptr, pic_origin_y) *
-                               na_unit_ptr->unit_size);
+                           get_neighbor_array_unit_left_index(na_unit_ptr, pic_origin_y) * na_unit_ptr->unit_size);
     svt_memcpy(dst_ptr, src_ptr_left, block_height * sizeof(uint16_t));
 
     //   Top-left Neighbor Array
@@ -273,7 +252,7 @@ void update_recon_neighbor_array16bit(NeighborArrayUnit *na_unit_ptr, uint16_t *
 
     // Copy bottom row
     dst_ptr = (uint16_t *)(na_unit_ptr->top_left_array +
-                           get_neighbor_array_unit_top_left_index(
+                           svt_aom_get_neighbor_array_unit_top_left_index(
                                na_unit_ptr, pic_origin_x, pic_origin_y + (block_height - 1)) *
                                na_unit_ptr->unit_size);
     svt_memcpy(dst_ptr, read_ptr, block_width * sizeof(uint16_t));
@@ -283,7 +262,7 @@ void update_recon_neighbor_array16bit(NeighborArrayUnit *na_unit_ptr, uint16_t *
 
     // Copy right column
     dst_ptr = (uint16_t *)(na_unit_ptr->top_left_array +
-                           get_neighbor_array_unit_top_left_index(
+                           svt_aom_get_neighbor_array_unit_top_left_index(
                                na_unit_ptr, pic_origin_x + (block_width - 1), pic_origin_y) *
                                na_unit_ptr->unit_size);
 
@@ -302,11 +281,10 @@ void update_recon_neighbor_array16bit(NeighborArrayUnit *na_unit_ptr, uint16_t *
 /*************************************************
  * Neighbor Array Sample Update
  *************************************************/
-void neighbor_array_unit_sample_write(NeighborArrayUnit *na_unit_ptr, uint8_t *src_ptr,
-                                      uint32_t stride, uint32_t src_origin_x, uint32_t src_origin_y,
-                                      uint32_t pic_origin_x, uint32_t pic_origin_y,
-                                      uint32_t block_width, uint32_t block_height,
-                                      uint32_t neighbor_array_type_mask) {
+void svt_aom_neighbor_array_unit_sample_write(NeighborArrayUnit *na_unit_ptr, uint8_t *src_ptr, uint32_t stride,
+                                              uint32_t src_origin_x, uint32_t src_origin_y, uint32_t pic_origin_x,
+                                              uint32_t pic_origin_y, uint32_t block_width, uint32_t block_height,
+                                              uint8_t neighbor_array_type_mask) {
     uint32_t idx;
     uint8_t *dst_ptr;
     uint8_t *read_ptr;
@@ -332,7 +310,7 @@ void neighbor_array_unit_sample_write(NeighborArrayUnit *na_unit_ptr, uint8_t *s
         //  The top neighbor array is updated with the samples from the
         //    bottom row of the source block
         //
-        //  Index = origin_x
+        //  Index = org_x
 
         // Adjust read_ptr to the bottom-row
         read_ptr = src_ptr + ((block_height - 1) * stride);
@@ -367,7 +345,7 @@ void neighbor_array_unit_sample_write(NeighborArrayUnit *na_unit_ptr, uint8_t *s
         //  The left neighbor array is updated with the samples from the
         //    right column of the source block
         //
-        //  Index = origin_y
+        //  Index = org_y
 
         // Adjust read_ptr to the right-column
         read_ptr = src_ptr + (block_width - 1);
@@ -404,7 +382,7 @@ void neighbor_array_unit_sample_write(NeighborArrayUnit *na_unit_ptr, uint8_t *s
         //  The top-left neighbor array is updated with the reversed samples
         //    from the right column and bottom row of the source block
         //
-        // Index = origin_x - origin_y
+        // Index = org_x - org_y
         */
 
         // Adjust read_ptr to the bottom-row
@@ -412,7 +390,7 @@ void neighbor_array_unit_sample_write(NeighborArrayUnit *na_unit_ptr, uint8_t *s
 
         // Copy bottom row
         dst_ptr = na_unit_ptr->top_left_array +
-            get_neighbor_array_unit_top_left_index(
+            svt_aom_get_neighbor_array_unit_top_left_index(
                 na_unit_ptr, pic_origin_x, pic_origin_y + (block_height - 1)) *
                 na_unit_ptr->unit_size;
 
@@ -423,7 +401,7 @@ void neighbor_array_unit_sample_write(NeighborArrayUnit *na_unit_ptr, uint8_t *s
 
         // Copy right column
         dst_ptr = na_unit_ptr->top_left_array +
-            get_neighbor_array_unit_top_left_index(
+            svt_aom_get_neighbor_array_unit_top_left_index(
                 na_unit_ptr, pic_origin_x + (block_width - 1), pic_origin_y) *
                 na_unit_ptr->unit_size;
 
@@ -445,12 +423,10 @@ void neighbor_array_unit_sample_write(NeighborArrayUnit *na_unit_ptr, uint8_t *s
 /*************************************************
  * Neighbor Array Sample Update for 16 bit case
  *************************************************/
-void neighbor_array_unit16bit_sample_write(NeighborArrayUnit *na_unit_ptr, uint16_t *src_ptr,
-                                           uint32_t stride, uint32_t src_origin_x,
-                                           uint32_t src_origin_y, uint32_t pic_origin_x,
-                                           uint32_t pic_origin_y, uint32_t block_width,
-                                           uint32_t block_height,
-                                           uint32_t neighbor_array_type_mask) {
+void svt_aom_neighbor_array_unit16bit_sample_write(NeighborArrayUnit *na_unit_ptr, uint16_t *src_ptr, uint32_t stride,
+                                                   uint32_t src_origin_x, uint32_t src_origin_y, uint32_t pic_origin_x,
+                                                   uint32_t pic_origin_y, uint32_t block_width, uint32_t block_height,
+                                                   uint8_t neighbor_array_type_mask) {
     uint32_t  idx;
     uint16_t *dst_ptr;
     uint16_t *read_ptr;
@@ -476,7 +452,7 @@ void neighbor_array_unit16bit_sample_write(NeighborArrayUnit *na_unit_ptr, uint1
         //  The top neighbor array is updated with the samples from the
         //    bottom row of the source block
         //
-        //  Index = origin_x
+        //  Index = org_x
 
         // Adjust read_ptr to the bottom-row
         read_ptr = src_ptr + ((block_height - 1) * stride);
@@ -510,7 +486,7 @@ void neighbor_array_unit16bit_sample_write(NeighborArrayUnit *na_unit_ptr, uint1
         //  The left neighbor array is updated with the samples from the
         //    right column of the source block
         //
-        //  Index = origin_y
+        //  Index = org_y
 
         // Adjust read_ptr to the right-column
         read_ptr = src_ptr + (block_width - 1);
@@ -548,7 +524,7 @@ void neighbor_array_unit16bit_sample_write(NeighborArrayUnit *na_unit_ptr, uint1
         //  The top-left neighbor array is updated with the reversed samples
         //    from the right column and bottom row of the source block
         //
-        // Index = origin_x - origin_y
+        // Index = org_x - org_y
         */
 
         // Adjust read_ptr to the bottom-row
@@ -556,7 +532,7 @@ void neighbor_array_unit16bit_sample_write(NeighborArrayUnit *na_unit_ptr, uint1
 
         // Copy bottom row
         dst_ptr = (uint16_t *)(na_unit_ptr->top_left_array) +
-            get_neighbor_array_unit_top_left_index(
+            svt_aom_get_neighbor_array_unit_top_left_index(
                       na_unit_ptr, pic_origin_x, pic_origin_y + (block_height - 1));
 
         dst_step  = 1;
@@ -575,9 +551,9 @@ void neighbor_array_unit16bit_sample_write(NeighborArrayUnit *na_unit_ptr, uint1
 
         // Copy right column
         dst_ptr = (uint16_t *)(na_unit_ptr->top_left_array) +
-            get_neighbor_array_unit_top_left_index(na_unit_ptr,
-                                                   pic_origin_x + (block_width - 1),
-                                                   pic_origin_y); //CHKN  * na_unit_ptr->unit_size;
+            svt_aom_get_neighbor_array_unit_top_left_index(na_unit_ptr,
+                                                           pic_origin_x + (block_width - 1),
+                                                           pic_origin_y); //CHKN  * na_unit_ptr->unit_size;
 
         dst_step  = -1;
         read_step = stride;
@@ -596,9 +572,9 @@ void neighbor_array_unit16bit_sample_write(NeighborArrayUnit *na_unit_ptr, uint1
 /*************************************************
  * Neighbor Array Unit Mode Write
  *************************************************/
-void neighbor_array_unit_mode_write32(NeighborArrayUnit32 *na_unit_ptr, uint32_t value,
-                                      uint32_t origin_x, uint32_t origin_y, uint32_t block_width,
-                                      uint32_t block_height, uint32_t neighbor_array_type_mask) {
+void svt_aom_neighbor_array_unit_mode_write32(NeighborArrayUnit32 *na_unit_ptr, uint32_t value, uint32_t org_x,
+                                              uint32_t org_y, uint32_t block_width, uint32_t block_height,
+                                              uint8_t neighbor_array_type_mask) {
     uint32_t  idx;
     uint32_t *dst_ptr;
 
@@ -622,9 +598,9 @@ void neighbor_array_unit_mode_write32(NeighborArrayUnit32 *na_unit_ptr, uint32_t
         //  The top neighbor array is updated with the samples from the
         //    bottom row of the source block
         //
-        //  Index = origin_x
+        //  Index = org_x
 
-        na_offset = get_neighbor_array_unit_top_index32(na_unit_ptr, origin_x);
+        na_offset = get_neighbor_array_unit_top_index32(na_unit_ptr, org_x);
 
         dst_ptr = na_unit_ptr->top_array + na_offset * na_unit_size;
 
@@ -652,9 +628,9 @@ void neighbor_array_unit_mode_write32(NeighborArrayUnit32 *na_unit_ptr, uint32_t
         //  The left neighbor array is updated with the samples from the
         //    right column of the source block
         //
-        //  Index = origin_y
+        //  Index = org_y
 
-        na_offset = get_neighbor_array_unit_left_index32(na_unit_ptr, origin_y);
+        na_offset = get_neighbor_array_unit_left_index32(na_unit_ptr, org_y);
 
         dst_ptr = na_unit_ptr->left_array + na_offset * na_unit_size;
 
@@ -684,11 +660,10 @@ void neighbor_array_unit_mode_write32(NeighborArrayUnit32 *na_unit_ptr, uint32_t
         //  The top-left neighbor array is updated with the reversed samples
         //    from the right column and bottom row of the source block
         //
-        // Index = origin_x - origin_y
+        // Index = org_x - org_y
         */
 
-        na_offset = get_neighbor_array_unit_top_left_index_32(
-            na_unit_ptr, origin_x, origin_y + (block_height - 1));
+        na_offset = get_neighbor_array_unit_top_left_index_32(na_unit_ptr, org_x, org_y + (block_height - 1));
 
         // Copy bottom-row + right-column
         // *Note - start from the bottom-left corner
@@ -706,9 +681,9 @@ void neighbor_array_unit_mode_write32(NeighborArrayUnit32 *na_unit_ptr, uint32_t
     return;
 }
 
-void neighbor_array_unit_mode_write(NeighborArrayUnit *na_unit_ptr, uint8_t *value,
-                                    uint32_t origin_x, uint32_t origin_y, uint32_t block_width,
-                                    uint32_t block_height, uint32_t neighbor_array_type_mask) {
+void svt_aom_neighbor_array_unit_mode_write(NeighborArrayUnit *na_unit_ptr, uint8_t *value, uint32_t org_x,
+                                            uint32_t org_y, uint32_t block_width, uint32_t block_height,
+                                            uint8_t neighbor_array_type_mask) {
     uint32_t idx, j;
     uint8_t *dst_ptr;
 
@@ -732,9 +707,9 @@ void neighbor_array_unit_mode_write(NeighborArrayUnit *na_unit_ptr, uint8_t *val
         //  The top neighbor array is updated with the samples from the
         //    bottom row of the source block
         //
-        //  Index = origin_x
+        //  Index = org_x
 
-        na_offset = get_neighbor_array_unit_top_index(na_unit_ptr, origin_x);
+        na_offset = get_neighbor_array_unit_top_index(na_unit_ptr, org_x);
 
         dst_ptr = na_unit_ptr->top_array + na_offset * na_unit_size;
 
@@ -763,9 +738,9 @@ void neighbor_array_unit_mode_write(NeighborArrayUnit *na_unit_ptr, uint8_t *val
         //  The left neighbor array is updated with the samples from the
         //    right column of the source block
         //
-        //  Index = origin_y
+        //  Index = org_y
 
-        na_offset = get_neighbor_array_unit_left_index(na_unit_ptr, origin_y);
+        na_offset = get_neighbor_array_unit_left_index(na_unit_ptr, org_y);
 
         dst_ptr = na_unit_ptr->left_array + na_offset * na_unit_size;
 
@@ -796,11 +771,10 @@ void neighbor_array_unit_mode_write(NeighborArrayUnit *na_unit_ptr, uint8_t *val
         //  The top-left neighbor array is updated with the reversed samples
         //    from the right column and bottom row of the source block
         //
-        // Index = origin_x - origin_y
+        // Index = org_x - org_y
         */
 
-        na_offset = get_neighbor_array_unit_top_left_index(
-            na_unit_ptr, origin_x, origin_y + (block_height - 1));
+        na_offset = svt_aom_get_neighbor_array_unit_top_left_index(na_unit_ptr, org_x, org_y + (block_height - 1));
 
         // Copy bottom-row + right-column
         // *Note - start from the bottom-left corner
@@ -819,9 +793,8 @@ void neighbor_array_unit_mode_write(NeighborArrayUnit *na_unit_ptr, uint8_t *val
     return;
 }
 
-void copy_neigh_arr(NeighborArrayUnit *na_src, NeighborArrayUnit *na_dst, uint32_t origin_x,
-                    uint32_t origin_y, uint32_t bw, uint32_t bh,
-                    uint32_t neighbor_array_type_mask) {
+void svt_aom_copy_neigh_arr(NeighborArrayUnit *na_src, NeighborArrayUnit *na_dst, uint32_t org_x, uint32_t org_y,
+                            uint32_t bw, uint32_t bh, uint8_t neighbor_array_type_mask) {
     uint32_t idx;
     uint8_t *dst_ptr, *src_ptr;
 
@@ -833,7 +806,7 @@ void copy_neigh_arr(NeighborArrayUnit *na_src, NeighborArrayUnit *na_dst, uint32
     na_unit_size = na_src->unit_size;
 
     if (neighbor_array_type_mask & NEIGHBOR_ARRAY_UNIT_TOP_MASK) {
-        na_offset = get_neighbor_array_unit_top_index(na_src, origin_x);
+        na_offset = get_neighbor_array_unit_top_index(na_src, org_x);
         src_ptr   = na_src->top_array + na_offset * na_unit_size;
         dst_ptr   = na_dst->top_array + na_offset * na_unit_size;
         count     = bw >> na_src->granularity_normal_log2;
@@ -842,7 +815,7 @@ void copy_neigh_arr(NeighborArrayUnit *na_src, NeighborArrayUnit *na_dst, uint32
     }
 
     if (neighbor_array_type_mask & NEIGHBOR_ARRAY_UNIT_LEFT_MASK) {
-        na_offset = get_neighbor_array_unit_left_index(na_src, origin_y);
+        na_offset = get_neighbor_array_unit_left_index(na_src, org_y);
         src_ptr   = na_src->left_array + na_offset * na_unit_size;
         dst_ptr   = na_dst->left_array + na_offset * na_unit_size;
         count     = bh >> na_src->granularity_normal_log2;
@@ -867,10 +840,10 @@ void copy_neigh_arr(NeighborArrayUnit *na_src, NeighborArrayUnit *na_dst, uint32
         //  The top-left neighbor array is updated with the reversed samples
         //    from the right column and bottom row of the source block
         //
-        // Index = origin_x - origin_y
+        // Index = org_x - org_y
         */
 
-        na_offset = get_neighbor_array_unit_top_left_index(na_src, origin_x, origin_y + (bh - 1));
+        na_offset = svt_aom_get_neighbor_array_unit_top_left_index(na_src, org_x, org_y + (bh - 1));
 
         // Copy bottom-row + right-column
         // *Note - start from the bottom-left corner
@@ -885,9 +858,8 @@ void copy_neigh_arr(NeighborArrayUnit *na_src, NeighborArrayUnit *na_dst, uint32
     return;
 }
 
-void copy_neigh_arr_32(NeighborArrayUnit32 *na_src, NeighborArrayUnit32 *na_dst, uint32_t origin_x,
-                       uint32_t origin_y, uint32_t bw, uint32_t bh,
-                       uint32_t neighbor_array_type_mask) {
+void svt_aom_copy_neigh_arr_32(NeighborArrayUnit32 *na_src, NeighborArrayUnit32 *na_dst, uint32_t org_x, uint32_t org_y,
+                               uint32_t bw, uint32_t bh, uint8_t neighbor_array_type_mask) {
     uint32_t  idx;
     uint32_t *dst_ptr, *src_ptr;
 
@@ -900,7 +872,7 @@ void copy_neigh_arr_32(NeighborArrayUnit32 *na_src, NeighborArrayUnit32 *na_dst,
     na_unit_size = na_src->unit_size;
 
     if (neighbor_array_type_mask & NEIGHBOR_ARRAY_UNIT_TOP_MASK) {
-        na_offset = get_neighbor_array_unit_top_index32(na_src, origin_x);
+        na_offset = get_neighbor_array_unit_top_index32(na_src, org_x);
         src_ptr   = na_src->top_array + na_offset;
         dst_ptr   = na_dst->top_array + na_offset;
         count     = bw >> na_src->granularity_normal_log2;
@@ -909,7 +881,7 @@ void copy_neigh_arr_32(NeighborArrayUnit32 *na_src, NeighborArrayUnit32 *na_dst,
     }
 
     if (neighbor_array_type_mask & NEIGHBOR_ARRAY_UNIT_LEFT_MASK) {
-        na_offset = get_neighbor_array_unit_left_index32(na_src, origin_y);
+        na_offset = get_neighbor_array_unit_left_index32(na_src, org_y);
         src_ptr   = na_src->left_array + na_offset;
         dst_ptr   = na_dst->left_array + na_offset;
         count     = bh >> na_src->granularity_normal_log2;
@@ -933,11 +905,10 @@ void copy_neigh_arr_32(NeighborArrayUnit32 *na_src, NeighborArrayUnit32 *na_dst,
         //  The top-left neighbor array is updated with the reversed samples
         //    from the right column and bottom row of the source block
         //
-        // Index = origin_x - origin_y
+        // Index = org_x - org_y
         */
 
-        na_offset = get_neighbor_array_unit_top_left_index_32(
-            na_src, origin_x, origin_y + (bh - 1));
+        na_offset = get_neighbor_array_unit_top_left_index_32(na_src, org_x, org_y + (bh - 1));
 
         // Copy bottom-row + right-column
         // *Note - start from the bottom-left corner
