@@ -20,10 +20,12 @@
  * Defines
  **************************************/
 #define DEFAULT_QP 35
+// Have an unusual magic number to reduce probablity of user using them
+#define DEFAULT_TBR 2000513
 
 void svt_av1_print_lib_params(SequenceControlSet* scs);
 
-EbErrorType svt_av1_verify_settings(struct SequenceControlSet* scs_ptr);
+EbErrorType svt_av1_verify_settings(struct SequenceControlSet* scs);
 
 EbErrorType svt_av1_set_default_params(EbSvtAv1EncConfiguration* config_ptr);
 
