@@ -17,7 +17,7 @@
  * * svt_aom_cdef_find_dir_avx2
  * * svt_aom_cdef_find_dir_dual_avx2
  * * svt_cdef_filter_block_avx2
- * * compute_cdef_dist_16bit_avx2
+ * * svt_aom_compute_cdef_dist_16bit_avx2
  * * svt_aom_copy_rect8_8bit_to_16bit_avx2
  * * svt_search_one_dual_avx2
  *
@@ -54,10 +54,17 @@ typedef void (*svt_cdef_filter_block_8xn_16_func)(
 
 static const svt_cdef_filter_block_8xn_16_func
     svt_cdef_filter_block_8xn_16_func_table[] = {
+#if defined(ARCH_X86_64)
         svt_cdef_filter_block_8xn_16_avx2,
 #if EN_AVX512_SUPPORT
         svt_cdef_filter_block_8xn_16_avx512
 #endif
+#endif
+
+#if defined(ARCH_AARCH64)
+            NULL,  // No C version, only applicable for avx2 and avx512
+#endif
+
 };
 using cdef_dir_param_t =
     ::testing::tuple<CdefFilterBlockFunc, CdefFilterBlockFunc, BlockSize, int,
@@ -98,7 +105,9 @@ class CDEFBlockTest : public ::testing::TestWithParam<cdef_dir_param_t> {
         bsize_ = TEST_GET_PARAM(2);
         boundary_ = TEST_GET_PARAM(3);
         bd_ = TEST_GET_PARAM(4);
-        svt_cdef_filter_block_8xn_16 = TEST_GET_PARAM(5);
+        if (TEST_GET_PARAM(5) != NULL) {
+            svt_cdef_filter_block_8xn_16 = TEST_GET_PARAM(5);
+        }
 
         memset(dst_ref_, 0, sizeof(dst_ref_));
         memset(dst_tst_, 0, sizeof(dst_tst_));
@@ -364,6 +373,8 @@ TEST_P(CDEFBlockTest, DISABLED_SpeedTest) {
     speed_cdef();
 }
 
+#if defined(ARCH_X86_64)
+
 // VS compiling for 32 bit targets does not support vector types in
 // structs as arguments, which makes the v256 type of the intrinsics
 // hard to support, so optimizations for this target are disabled.
@@ -387,6 +398,19 @@ INSTANTIATE_TEST_CASE_P(
         ::testing::ValuesIn(svt_cdef_filter_block_8xn_16_func_table)));
 
 #endif  // defined(_WIN64) || !defined(_MSC_VER)
+#endif  // defined(ARCH_X86_64)
+
+#if defined(ARCH_AARCH64)
+INSTANTIATE_TEST_CASE_P(
+    Cdef_neon, CDEFBlockTest,
+    ::testing::Combine(
+        ::testing::Values(&svt_cdef_filter_block_neon),
+        ::testing::Values(&svt_cdef_filter_block_c),
+        ::testing::Values(BLOCK_4X4, BLOCK_4X8, BLOCK_8X4, BLOCK_8X8),
+        ::testing::Range(0, 16), ::testing::Range(8, 13, 2),
+        ::testing::ValuesIn(svt_cdef_filter_block_8xn_16_func_table)));
+#endif  // defined(ARCH_AARCH64)
+
 using FindDirFunc = uint8_t (*)(const uint16_t *img, int stride, int32_t *var,
                                 int coeff_shift);
 using TestFindDirParam = ::testing::tuple<FindDirFunc, FindDirFunc>;
@@ -472,6 +496,8 @@ TEST_P(CDEFFindDirTest, MatchTest) {
     test_finddir();
 }
 
+#if defined(ARCH_X86_64)
+
 // VS compiling for 32 bit targets does not support vector types in
 // structs as arguments, which makes the v256 type of the intrinsics
 // hard to support, so optimizations for this target are disabled.
@@ -483,6 +509,17 @@ INSTANTIATE_TEST_CASE_P(
         make_tuple(&svt_aom_cdef_find_dir_avx2, &svt_aom_cdef_find_dir_c)));
 #endif  // defined(_WIN64) || !defined(_MSC_VER)
 
+#endif  // defined(ARCH_X86_64)
+
+#if defined(ARCH_AARCH64)
+
+INSTANTIATE_TEST_CASE_P(
+    Cdef, CDEFFindDirTest,
+    ::testing::Values(make_tuple(&svt_aom_cdef_find_dir_neon,
+                                 &svt_aom_cdef_find_dir_c)));
+
+#endif
+
 using FindDirDualFunc = void (*)(const uint16_t *img1, const uint16_t *img2,
                                  int stride, int32_t *var1, int32_t *var2,
                                  int32_t coeff_shift, uint8_t *out1,
@@ -601,6 +638,8 @@ TEST_P(CDEFFindDirDualTest, MatchTest) {
     test_finddir();
 }
 
+#if defined(ARCH_X86_64)
+
 // VS compiling for 32 bit targets does not support vector types in
 // structs as arguments, which makes the v256 type of the intrinsics
 // hard to support, so optimizations for this target are disabled.
@@ -613,8 +652,22 @@ INSTANTIATE_TEST_CASE_P(
                                  &svt_aom_cdef_find_dir_dual_c)));
 
 #endif  // defined(_WIN64) || !defined(_MSC_VER)
+
+#endif  // defined(ARCH_X86_64)
+
+#if defined(ARCH_AARCH64)
+
+INSTANTIATE_TEST_CASE_P(
+    Cdef, CDEFFindDirDualTest,
+    ::testing::Values(make_tuple(&svt_aom_cdef_find_dir_dual_neon,
+                                 &svt_aom_cdef_find_dir_dual_c)));
+
+#endif  // defined(ARCH_AARCH64)
+
 }  // namespace
 
+#if defined(ARCH_X86_64)
+
 /**
  * @brief Unit test for svt_aom_copy_rect8_8bit_to_16bit_avx2
  *
@@ -657,6 +710,9 @@ TEST(CdefToolTest, CopyRectMatchTest) {
 
             svt_aom_copy_rect8_8bit_to_16bit_c(
                 dst_ref_, CDEF_BSTRIDE, src_, CDEF_BSTRIDE, vsize, hsize);
+
+            // Test the SSE4.1 copy function
+            memset(dst_data_tst_, 0, sizeof(dst_data_tst_));
             svt_aom_copy_rect8_8bit_to_16bit_sse4_1(
                 dst_tst_, CDEF_BSTRIDE, src_, CDEF_BSTRIDE, vsize, hsize);
 
@@ -681,9 +737,10 @@ TEST(CdefToolTest, CopyRectMatchTest) {
             }
         }
 }
+#endif  // defined(ARCH_X86_64)
 
 /**
- * @brief Unit test for compute_cdef_dist_16bit_avx2
+ * @brief Unit test for svt_aom_compute_cdef_dist_16bit_avx2
  *
  * Test strategy:
  * Feed cdef list, src buffer, dst buffer generated randomly to targeted
@@ -740,7 +797,42 @@ TEST(CdefToolTest, ComputeCdefDistMatchTest) {
                     // Allowable subsampling values are: 1, 2
                     for (uint8_t subsampling = 1; subsampling <= 2;
                          subsampling <<= 1) {
-                        const uint64_t c_mse = compute_cdef_dist_c(dst_data_,
+                        const uint64_t c_mse =
+                            svt_aom_compute_cdef_dist_c(dst_data_,
+                                                        stride,
+                                                        src_data_,
+                                                        dlist,
+                                                        cdef_count,
+                                                        test_bs[i],
+                                                        coeff_shift,
+                                                        plane,
+                                                        subsampling);
+
+#if defined(ARCH_AARCH64)
+
+                        // NEON
+                        const uint64_t neon_mse =
+                            svt_aom_compute_cdef_dist_16bit_neon(dst_data_,
+                                                                 stride,
+                                                                 src_data_,
+                                                                 dlist,
+                                                                 cdef_count,
+                                                                 test_bs[i],
+                                                                 coeff_shift,
+                                                                 plane,
+                                                                 subsampling);
+                        ASSERT_EQ(c_mse, neon_mse)
+                            << "svt_aom_compute_cdef_dist_16bit_sse4_1 failed "
+                            << "bitdepth: " << bd << " plane: " << plane
+                            << " BlockSize " << test_bs[i] << " loop: " << k;
+
+#endif  // if defined(ARCH_AARCH64)
+
+#if defined(ARCH_X86_64)
+
+                        // SSE4.1
+                        const uint64_t sse_mse =
+                            svt_aom_compute_cdef_dist_16bit_sse4_1(dst_data_,
                                                                    stride,
                                                                    src_data_,
                                                                    dlist,
@@ -749,34 +841,28 @@ TEST(CdefToolTest, ComputeCdefDistMatchTest) {
                                                                    coeff_shift,
                                                                    plane,
                                                                    subsampling);
-                        const uint64_t sse_mse =
-                            compute_cdef_dist_16bit_sse4_1(dst_data_,
-                                                           stride,
-                                                           src_data_,
-                                                           dlist,
-                                                           cdef_count,
-                                                           test_bs[i],
-                                                           coeff_shift,
-                                                           plane,
-                                                           subsampling);
-                        const uint64_t avx_mse =
-                            compute_cdef_dist_16bit_avx2(dst_data_,
-                                                         stride,
-                                                         src_data_,
-                                                         dlist,
-                                                         cdef_count,
-                                                         test_bs[i],
-                                                         coeff_shift,
-                                                         plane,
-                                                         subsampling);
                         ASSERT_EQ(c_mse, sse_mse)
-                            << "compute_cdef_dist_16bit_sse4_1 failed "
+                            << "svt_aom_compute_cdef_dist_16bit_sse4_1 failed "
                             << "bitdepth: " << bd << " plane: " << plane
                             << " BlockSize " << test_bs[i] << " loop: " << k;
+
+                        // AVX2
+                        const uint64_t avx_mse =
+                            svt_aom_compute_cdef_dist_16bit_avx2(dst_data_,
+                                                                 stride,
+                                                                 src_data_,
+                                                                 dlist,
+                                                                 cdef_count,
+                                                                 test_bs[i],
+                                                                 coeff_shift,
+                                                                 plane,
+                                                                 subsampling);
                         ASSERT_EQ(c_mse, avx_mse)
-                            << "compute_cdef_dist_16bit_avx2 failed "
+                            << "svt_aom_compute_cdef_dist_16bit_avx2 failed "
                             << "bitdepth: " << bd << " plane: " << plane
                             << " BlockSize " << test_bs[i] << " loop: " << k;
+
+#endif  // defined(ARCH_X86_64)
                     }
                 }
             }
@@ -784,6 +870,8 @@ TEST(CdefToolTest, ComputeCdefDistMatchTest) {
     }
 }
 
+#if defined(ARCH_X86_64)
+
 TEST(CdefToolTest, ComputeCdefDist8bitMatchTest) {
     const int stride = 1 << MAX_SB_SIZE_LOG2;
     const int buf_size = 1 << (MAX_SB_SIZE_LOG2 * 2);
@@ -825,41 +913,44 @@ TEST(CdefToolTest, ComputeCdefDist8bitMatchTest) {
                     for (uint8_t subsampling = 1; subsampling <= 2;
                          subsampling <<= 1) {
                         const uint64_t c_mse =
-                            compute_cdef_dist_8bit_c(dst_data_,
-                                                     stride,
-                                                     src_data_,
-                                                     dlist,
-                                                     cdef_count,
-                                                     test_bs[i],
-                                                     coeff_shift,
-                                                     plane,
-                                                     subsampling);
+                            svt_aom_compute_cdef_dist_8bit_c(dst_data_,
+                                                             stride,
+                                                             src_data_,
+                                                             dlist,
+                                                             cdef_count,
+                                                             test_bs[i],
+                                                             coeff_shift,
+                                                             plane,
+                                                             subsampling);
+                        // SSE4.1
                         const uint64_t sse_mse =
-                            compute_cdef_dist_8bit_sse4_1(dst_data_,
-                                                          stride,
-                                                          src_data_,
-                                                          dlist,
-                                                          cdef_count,
-                                                          test_bs[i],
-                                                          coeff_shift,
-                                                          plane,
-                                                          subsampling);
-                        const uint64_t avx_mse =
-                            compute_cdef_dist_8bit_avx2(dst_data_,
-                                                        stride,
-                                                        src_data_,
-                                                        dlist,
-                                                        cdef_count,
-                                                        test_bs[i],
-                                                        coeff_shift,
-                                                        plane,
-                                                        subsampling);
+                            svt_aom_compute_cdef_dist_8bit_sse4_1(dst_data_,
+                                                                  stride,
+                                                                  src_data_,
+                                                                  dlist,
+                                                                  cdef_count,
+                                                                  test_bs[i],
+                                                                  coeff_shift,
+                                                                  plane,
+                                                                  subsampling);
                         ASSERT_EQ(c_mse, sse_mse)
-                            << "compute_cdef_dist_8bit_sse4_1 failed "
+                            << "svt_aom_compute_cdef_dist_8bit_sse4_1 failed "
                             << "bitdepth: " << bd << " plane: " << plane
                             << " BlockSize " << test_bs[i] << " loop: " << k;
+
+                        // AVX2
+                        const uint64_t avx_mse =
+                            svt_aom_compute_cdef_dist_8bit_avx2(dst_data_,
+                                                                stride,
+                                                                src_data_,
+                                                                dlist,
+                                                                cdef_count,
+                                                                test_bs[i],
+                                                                coeff_shift,
+                                                                plane,
+                                                                subsampling);
                         ASSERT_EQ(c_mse, avx_mse)
-                            << "compute_cdef_dist_8bit_avx2 failed "
+                            << "svt_aom_compute_cdef_dist_8bit_avx2 failed "
                             << "bitdepth: " << bd << " plane: " << plane
                             << " BlockSize " << test_bs[i] << " loop: " << k;
                     }
@@ -868,6 +959,7 @@ TEST(CdefToolTest, ComputeCdefDist8bitMatchTest) {
         }
     }
 }
+#endif  // defined(ARCH_X86_64)
 
 /**
  * @brief Unit test for svt_search_one_dual_avx2
@@ -893,10 +985,12 @@ typedef uint64_t (*svt_search_one_dual_func)(int *lev0, int *lev1,
                                              int start_gi, int end_gi);
 
 static const svt_search_one_dual_func search_one_dual_func_table[] = {
+#if defined(ARCH_X86_64)
     svt_search_one_dual_avx2,
 #if EN_AVX512_SUPPORT
     svt_search_one_dual_avx512
 #endif
+#endif
 };
 
 TEST(CdefToolTest, SearchOneDualMatchTest) {
