@@ -118,10 +118,9 @@ static const vector<SvtAv1IntraRefreshType> default_intra_refresh_type = {
 };
 static const vector<SvtAv1IntraRefreshType> valid_intra_refresh_type = {
     SVT_AV1_FWDKF_REFRESH,  // CRA, open GOP
-    SVT_AV1_KF_REFRESH,  // IDR, closed GOP
-};
-static const vector<SvtAv1IntraRefreshType> invalid_intra_refresh_type = {
+    SVT_AV1_KF_REFRESH,     // IDR, closed GOP
 };
+static const vector<SvtAv1IntraRefreshType> invalid_intra_refresh_type = {};
 
 /* Number of hierarchical layers used to construct GOP.
  * Minigop size = 2^HierarchicalLevels.
@@ -148,23 +147,25 @@ static const vector<uint32_t> invalid_hierarchical_levels = {
  * same reference picture.
  *
  * Following values are supported and defined in EbDefinitions.h
- * #define EB_PRED_LOW_DELAY_P     0
- * #define EB_PRED_LOW_DELAY_B     1
- * #define EB_PRED_RANDOM_ACCESS   2
- * #define EB_PRED_TOTAL_COUNT     3
+ * #define SVT_AV1_PRED_LOW_DELAY_P     0
+ * #define SVT_AV1_PRED_LOW_DELAY_B     1
+ * #define SVT_AV1_PRED_RANDOM_ACCESS   2
+ * #define SVT_AV1_PRED_TOTAL_COUNT     3
 
  * In Random Access structure, the b/b pictures can refer to reference pictures
  * from both directions (past and future).
  *
  * Default is 2. */
 static const vector<uint8_t> default_pred_structure = {
-    EB_PRED_RANDOM_ACCESS,
+    SVT_AV1_PRED_RANDOM_ACCESS,
 };
 static const vector<uint8_t> valid_pred_structure = {
-    EB_PRED_LOW_DELAY_P, EB_PRED_LOW_DELAY_B, EB_PRED_RANDOM_ACCESS};
+    SVT_AV1_PRED_LOW_DELAY_P,
+    SVT_AV1_PRED_LOW_DELAY_B,
+    SVT_AV1_PRED_RANDOM_ACCESS};
 static const vector<uint8_t> invalid_pred_structure = {
     /* _pred_structure override in code
-    EB_PRED_TOTAL_COUNT, EB_PRED_TOTAL_COUNT + 1, EB_PRED_INVALID*/};
+    SVT_AV1_PRED_TOTAL_COUNT, SVT_AV1_PRED_TOTAL_COUNT + 1, EB_PRED_INVALID*/};
 
 // Input Info
 /* The width of input source in units of picture luma pixels.
@@ -193,36 +194,6 @@ static const vector<uint32_t> invalid_source_height = {
     0, 1, 2, 4, 8, 16, 32, 63, 65, 2161,  // ...
 };
 
-/* The frequecy of images being displayed. If the number is less than 1000,
- * the input frame rate is an integer number between 1 and 60, else the input
- * number is in Q16 format, shifted by 16 bits, where max allowed is 240 fps.
- * If FrameRateNumerator and FrameRateDenominator are both not equal to zero,
- * the encoder will ignore this parameter.
- *
- * Default is 25. */
-static const vector<uint32_t> default_frame_rate = {
-    30 << 16,
-};
-static const vector<uint32_t> valid_frame_rate = {
-    1,
-    24,
-    25,
-    30,
-    50,
-    60,
-    1 << 16,
-    24 << 16,
-    25 << 16,
-    30 << 16,
-    50 << 16,
-    60 << 16,
-    120 << 16,
-    240 << 16,
-};
-static const vector<uint32_t> invalid_frame_rate = {
-    0, 241 << 16, 0xFFFFFFFF  // ...
-};
-
 // TODO: follwoing two parameters should be a combination test
 /* Frame rate numerator. When zero, the encoder will use -fps if
  * FrameRateDenominator is also zero, otherwise an error is returned.
@@ -395,30 +366,29 @@ static const vector<uint32_t> invalid_qp = {
 /* force qp values for every picture that are passed in the header pointer
  *
  * Default is 0.*/
-static const vector<EbBool> default_use_qp_file = {
-    EB_FALSE,
+static const vector<Bool> default_use_qp_file = {
+    FALSE,
 };
-static const vector<EbBool> valid_use_qp_file = {
-    EB_FALSE,
-    EB_TRUE,
+static const vector<Bool> valid_use_qp_file = {
+    FALSE,
+    TRUE,
 };
-static const vector<EbBool> invalid_use_qp_file = {
+static const vector<Bool> invalid_use_qp_file = {
     // none
 };
 
-
 // Deblock Filter
 /* Flag to enable the Deblocking Loop Filtering.
  *
  * Default is true. */
-static const vector<EbBool> default_enable_dlf_flag = {
-    EB_TRUE,
+static const vector<Bool> default_enable_dlf_flag = {
+    TRUE,
 };
-static const vector<EbBool> valid_enable_dlf_flag = {
-    EB_FALSE,
-    EB_TRUE,
+static const vector<Bool> valid_enable_dlf_flag = {
+    FALSE,
+    TRUE,
 };
-static const vector<EbBool> invalid_enable_dlf_flag = {
+static const vector<Bool> invalid_enable_dlf_flag = {
     // none
 };
 
@@ -427,13 +397,13 @@ static const vector<EbBool> invalid_enable_dlf_flag = {
  *
  * Default is 0. */
 // TODO: the description of this parameter is incorrect, refer to source code,
-// it should be a EbBool
+// it should be a Bool
 static const vector<uint32_t> default_film_grain_denoise_strength = {
-    EB_FALSE,
+    FALSE,
 };
 static const vector<uint32_t> valid_film_grain_denoise_strength = {
-    EB_FALSE,
-    EB_TRUE,
+    FALSE,
+    TRUE,
 };
 static const vector<uint32_t> invalid_film_grain_denoise_strength = {
     // none
@@ -442,70 +412,70 @@ static const vector<uint32_t> invalid_film_grain_denoise_strength = {
 /* Warped motion
  *
  * Default is 0. */
-static const vector<EbBool> default_enable_warped_motion = {
-    EB_TRUE,
+static const vector<Bool> default_enable_warped_motion = {
+    TRUE,
 };
-static const vector<EbBool> valid_enable_warped_motion = {
-    EB_FALSE,
-    EB_TRUE,
+static const vector<Bool> valid_enable_warped_motion = {
+    FALSE,
+    TRUE,
 };
-static const vector<EbBool> invalid_enable_warped_motion = {
+static const vector<Bool> invalid_enable_warped_motion = {
     // none
 };
 
 /* Global motion
  *
  * Default is 1. */
-static const vector<EbBool> default_enable_global_motion = {
-    EB_TRUE,
+static const vector<Bool> default_enable_global_motion = {
+    TRUE,
 };
-static const vector<EbBool> valid_enable_global_motion = {
-    EB_FALSE,
-    EB_TRUE,
+static const vector<Bool> valid_enable_global_motion = {
+    FALSE,
+    TRUE,
 };
-static const vector<EbBool> invalid_enable_global_motion = {
+static const vector<Bool> invalid_enable_global_motion = {
     // none
 };
 
 /* Flag to enable the use of default ME HME parameters.
  *
  * Default is 1. */
-static const vector<EbBool> default_use_default_me_hme = {
-    EB_TRUE,
+static const vector<Bool> default_use_default_me_hme = {
+    TRUE,
 };
-static const vector<EbBool> valid_use_default_me_hme = {
-    EB_FALSE,
-    EB_TRUE,
+static const vector<Bool> valid_use_default_me_hme = {
+    FALSE,
+    TRUE,
 };
-static const vector<EbBool> invalid_use_default_me_hme = {
+static const vector<Bool> invalid_use_default_me_hme = {
     // none
 };
 
 /* Flag to enable Hierarchical Motion Estimation.
  *
  * Default is 1. */
-static const vector<EbBool> default_enable_hme_flag = {
-    EB_TRUE,
+static const vector<Bool> default_enable_hme_flag = {
+    TRUE,
 };
-static const vector<EbBool> valid_enable_hme_flag = {
-    EB_FALSE,
-    EB_TRUE,
+static const vector<Bool> valid_enable_hme_flag = {
+    FALSE,
+    TRUE,
 };
-static const vector<EbBool> invalid_enable_hme_flag = {
+static const vector<Bool> invalid_enable_hme_flag = {
     // none
 };
 
 /* Flag to enable the use of non-swaure partitions
  *
  * Default is 0. */
-static const vector<EbBool> default_ext_block_flag = {
-    EB_FALSE,
+static const vector<Bool> default_ext_block_flag = {
+    FALSE,
 };
-static const vector<EbBool> valid_ext_block_flag = {
-    EB_FALSE,
-    EB_TRUE,
+static const vector<Bool> valid_ext_block_flag = {
+    FALSE,
+    TRUE,
 };
-static const vector<EbBool> invalid_ext_block_flag = {
+static const vector<Bool> invalid_ext_block_flag = {
     // none
 };
 
@@ -556,14 +526,14 @@ static const vector<int32_t> invalid_palette_level = {-2, 7};
  * parameter sets in the elementary streams .
  *
  * Default is 0. */
-static const vector<EbBool> default_constrained_intra = {
-    EB_FALSE,
+static const vector<Bool> default_constrained_intra = {
+    FALSE,
 };
-static const vector<EbBool> valid_constrained_intra = {
-    EB_FALSE,
-    EB_TRUE,
+static const vector<Bool> valid_constrained_intra = {
+    FALSE,
+    TRUE,
 };
-static const vector<EbBool> invalid_constrained_intra = {
+static const vector<Bool> invalid_constrained_intra = {
     // none
 };
 
@@ -741,28 +711,32 @@ static const vector<uint32_t> invalid_level = {
  * 1 = up to AVX512, auto-select highest assembly instruction set supported.
  *
  * Default is 1. */
-static const vector<CPU_FLAGS> default_use_cpu_flags = {
-    CPU_FLAGS_ALL,
+static const vector<EbCpuFlags> default_use_cpu_flags = {
+    EB_CPU_FLAGS_ALL,
 };
-static const vector<CPU_FLAGS> valid_use_cpu_flags = {
-    CPU_FLAGS_MMX,
-    CPU_FLAGS_SSE,
-    CPU_FLAGS_SSE2,
-    CPU_FLAGS_SSE3,
-    CPU_FLAGS_SSSE3,
-    CPU_FLAGS_SSE4_1,
-    CPU_FLAGS_SSE4_2,
-    CPU_FLAGS_AVX,
-    CPU_FLAGS_AVX2,
-    CPU_FLAGS_AVX512F,
-    CPU_FLAGS_AVX512CD,
-    CPU_FLAGS_AVX512DQ,
-    CPU_FLAGS_AVX512ER,
-    CPU_FLAGS_AVX512PF,
-    CPU_FLAGS_AVX512BW,
-    CPU_FLAGS_AVX512VL,
+static const vector<EbCpuFlags> valid_use_cpu_flags = {
+#ifdef ARCH_X86_64
+    EB_CPU_FLAGS_MMX,
+    EB_CPU_FLAGS_SSE,
+    EB_CPU_FLAGS_SSE2,
+    EB_CPU_FLAGS_SSE3,
+    EB_CPU_FLAGS_SSSE3,
+    EB_CPU_FLAGS_SSE4_1,
+    EB_CPU_FLAGS_SSE4_2,
+    EB_CPU_FLAGS_AVX,
+    EB_CPU_FLAGS_AVX2,
+    EB_CPU_FLAGS_AVX512F,
+    EB_CPU_FLAGS_AVX512CD,
+    EB_CPU_FLAGS_AVX512DQ,
+    EB_CPU_FLAGS_AVX512ER,
+    EB_CPU_FLAGS_AVX512PF,
+    EB_CPU_FLAGS_AVX512BW,
+    EB_CPU_FLAGS_AVX512VL,
+#elif defined(ARCH_AARCH64)
+    EB_CPU_FLAGS_NEON,
+#endif
 };
-static const vector<CPU_FLAGS> invalid_use_cpu_flags = {CPU_FLAGS_INVALID};
+static const vector<EbCpuFlags> invalid_use_cpu_flags = {EB_CPU_FLAGS_INVALID};
 
 // Application Specific parameters
 /**
@@ -880,12 +854,12 @@ static const vector<int32_t> invalid_target_socket = {
  * ReconFile token (-o) and using the feature will affect the speed of encoder.
  *
  * Default is 0. */
-static const vector<uint32_t> default_recon_enabled = {EB_FALSE};
-static const vector<uint32_t> valid_recon_enabled = {EB_FALSE, EB_TRUE};
+static const vector<uint32_t> default_recon_enabled = {FALSE};
+static const vector<uint32_t> valid_recon_enabled = {FALSE, TRUE};
 static const vector<uint32_t> invalid_recon_enabled = {/** none */};
 
 #if TILES
-/* Log 2 Tile Rows and colums . 0 means no tiling,1 means that we split the
+/* Log 2 Tile Rows and columns . 0 means no tiling,1 means that we split the
  * dimension into 2 Default is 0. */
 static const vector<int32_t> default_tile_columns = {
     0,
@@ -931,9 +905,9 @@ static const vector<uint32_t> invalid_screen_content_mode = {3};
 
 /* Variables to control the use of ALT-REF (temporally filtered frames)
  */
-static const vector<EbBool> default_enable_tf = {EB_TRUE};
-static const vector<EbBool> valid_enable_tf = {EB_FALSE, EB_TRUE};
-static const vector<EbBool> invalid_enable_tf = {/*none*/};
+static const vector<Bool> default_enable_tf = {TRUE};
+static const vector<Bool> valid_enable_tf = {FALSE, TRUE};
+static const vector<Bool> invalid_enable_tf = {/*none*/};
 
 static const vector<uint8_t> default_altref_strength = {5};
 static const vector<uint8_t> valid_altref_strength = {0, 1, 2, 3, 4, 5, 6};
@@ -944,9 +918,9 @@ static const vector<uint8_t> valid_altref_nframes = {
     0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10};
 static const vector<uint8_t> invalid_altref_nframes = {11};
 
-static const vector<EbBool> default_enable_overlays = {EB_FALSE};
-static const vector<EbBool> valid_enable_overlays = {EB_FALSE, EB_TRUE};
-static const vector<EbBool> invalid_enable_overlays = {/*none*/};
+static const vector<Bool> default_enable_overlays = {FALSE};
+static const vector<Bool> valid_enable_overlays = {FALSE, TRUE};
+static const vector<Bool> invalid_enable_overlays = {/*none*/};
 
 /* Variables to control the super-resolution tool
  */
@@ -967,73 +941,83 @@ static const vector<uint8_t> invalid_superres_kf_denom = {7};
 // Color description
 /* Color range
  */
-static const vector<uint32_t> default_color_range = {0};
-static const vector<uint32_t> valid_color_range = {0, 1};
-static const vector<uint32_t> invalid_color_range = {};
+static const vector<EbColorRange> default_color_range = {EB_CR_STUDIO_RANGE};
+static const vector<EbColorRange> valid_color_range = {EB_CR_STUDIO_RANGE,
+                                                       EB_CR_FULL_RANGE};
+static const vector<EbColorRange> invalid_color_range = {};
 
 /* Color primaries
  */
-static const vector<uint32_t> default_color_primaries = {2};
-static const vector<uint32_t> valid_color_primaries = {
-    1,
-    2,
-    4,
-    5,
-    6,
-    7,
-    8,
-    9,
-    10,
-    11,
-    12,
-    22,
+static const vector<EbColorPrimaries> default_color_primaries = {
+    EB_CICP_CP_UNSPECIFIED};
+static const vector<EbColorPrimaries> valid_color_primaries = {
+    EB_CICP_CP_BT_709,
+    EB_CICP_CP_UNSPECIFIED,
+    EB_CICP_CP_BT_470_M,
+    EB_CICP_CP_BT_470_B_G,
+    EB_CICP_CP_BT_601,
+    EB_CICP_CP_SMPTE_240,
+    EB_CICP_CP_GENERIC_FILM,
+    EB_CICP_CP_BT_2020,
+    EB_CICP_CP_XYZ,
+    EB_CICP_CP_SMPTE_431,
+    EB_CICP_CP_SMPTE_432,
+    EB_CICP_CP_EBU_3213,
 };
-static const vector<uint32_t> invalid_color_primaries = {/*none*/};
+static const vector<EbColorPrimaries> invalid_color_primaries = {/*none*/};
 
 /* Transfer characteristics
  */
-static const vector<uint32_t> default_transfer_characteristics = {2};
-static const vector<uint32_t> valid_transfer_characteristics = {
-    1,
-    2,
-    4,
-    5,
-    6,
-    7,
-    8,
-    9,
-    10,
-    11,
-    12,
-    13,
-    14,
-    15,
-    16,
-    17,
-    18,
+static const vector<EbTransferCharacteristics>
+    default_transfer_characteristics = {
+        EB_CICP_TC_UNSPECIFIED,
 };
-static const vector<uint32_t> invalid_transfer_characteristics = {/*none*/};
+static const vector<EbTransferCharacteristics> valid_transfer_characteristics =
+    {
+        EB_CICP_TC_BT_709,
+        EB_CICP_TC_UNSPECIFIED,
+        EB_CICP_TC_BT_470_M,
+        EB_CICP_TC_BT_470_B_G,
+        EB_CICP_TC_BT_601,
+        EB_CICP_TC_SMPTE_240,
+        EB_CICP_TC_LINEAR,
+        EB_CICP_TC_LOG_100,
+        EB_CICP_TC_LOG_100_SQRT10,
+        EB_CICP_TC_IEC_61966,
+        EB_CICP_TC_BT_1361,
+        EB_CICP_TC_SRGB,
+        EB_CICP_TC_BT_2020_10_BIT,
+        EB_CICP_TC_BT_2020_12_BIT,
+        EB_CICP_TC_SMPTE_2084,
+        EB_CICP_TC_SMPTE_428,
+        EB_CICP_TC_HLG,
+};
+static const vector<EbTransferCharacteristics>
+    invalid_transfer_characteristics = {/*none*/};
 
 /* Matrix coeffricients
  */
-static const vector<uint32_t> default_matrix_coefficients = {2};
-static const vector<uint32_t> valid_matrix_coefficients = {
-    1,
-    2,
-    4,
-    5,
-    6,
-    7,
-    8,
-    9,
-    10,
-    11,
-    12,
-    13,
-    14,
+static const vector<EbMatrixCoefficients> default_matrix_coefficients = {
+    EB_CICP_MC_UNSPECIFIED,
+};
+static const vector<EbMatrixCoefficients> valid_matrix_coefficients = {
+    EB_CICP_MC_BT_709,
+    EB_CICP_MC_UNSPECIFIED,
+    EB_CICP_MC_FCC,
+    EB_CICP_MC_BT_470_B_G,
+    EB_CICP_MC_BT_601,
+    EB_CICP_MC_SMPTE_240,
+    EB_CICP_MC_SMPTE_YCGCO,
+    EB_CICP_MC_BT_2020_NCL,
+    EB_CICP_MC_BT_2020_CL,
+    EB_CICP_MC_SMPTE_2085,
+    EB_CICP_MC_CHROMAT_NCL,
+    EB_CICP_MC_CHROMAT_CL,
+    EB_CICP_MC_ICTCP,
+};
+static const vector<EbMatrixCoefficients> invalid_matrix_coefficients = {
+    EB_CICP_MC_IDENTITY,  // not actually invalid, but requires 4:4:4
 };
-static const vector<uint32_t> invalid_matrix_coefficients = {
-    0};  // not actually invalid, but requires 4:4:4
 
 }  // namespace svt_av1_test_params
 
